# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: qwak/traffic/v1/traffic.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1dqwak/traffic/v1/traffic.proto\x12\x0fqwak.traffic.v1\"J\n\x13MultipleHttpTraffic\x12\x33\n\rhttp_traffics\x18\x01 \x03(\x0b\x32\x1c.qwak.traffic.v1.HttpTraffic\"~\n\x0bHttpTraffic\x12\n\n\x02id\x18\x01 \x01(\t\x12\x32\n\x0broute_match\x18\x02 \x01(\x0b\x32\x1b.qwak.traffic.v1.RouteMatchH\x00\x12\r\n\x05order\x18\x03 \x01(\x05\x12\x10\n\x08group_id\x18\x04 \x01(\tB\x0e\n\x0chttp_traffic\"k\n\nRouteMatch\x12\x0c\n\x04path\x18\x01 \x01(\t\x12\'\n\x07matches\x18\x02 \x03(\x0b\x32\x16.qwak.traffic.v1.Match\x12&\n\x06routes\x18\x03 \x03(\x0b\x32\x16.qwak.traffic.v1.Route\"E\n\x05Match\x12\x34\n\x0cheader_match\x18\x01 \x01(\x0b\x32\x1c.qwak.traffic.v1.HeaderMatchH\x00\x42\x06\n\x04rule\"_\n\x0bHeaderMatch\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\x33\n\tcondition\x18\x02 \x01(\x0b\x32 .qwak.traffic.v1.HeaderCondition\x12\x0e\n\x06invert\x18\x03 \x01(\x08\"\xa4\x01\n\x0fHeaderCondition\x12\x42\n\x10\x62inary_condition\x18\x01 \x01(\x0b\x32&.qwak.traffic.v1.HeaderBinaryConditionH\x00\x12@\n\x0funary_condition\x18\x02 \x01(\x0b\x32%.qwak.traffic.v1.HeaderUnaryConditionH\x00\x42\x0b\n\tcondition\"]\n\x14HeaderUnaryCondition\x12\x34\n\x08operator\x18\x01 \x01(\x0e\x32\".qwak.traffic.v1.UnaryOperatorType\x12\x0f\n\x07operand\x18\x02 \x01(\t\"}\n\x15HeaderBinaryCondition\x12\x35\n\x08operator\x18\x01 \x01(\x0e\x32#.qwak.traffic.v1.BinaryOperatorType\x12\x15\n\rfirst_operand\x18\x02 \x01(\t\x12\x16\n\x0esecond_operand\x18\x03 \x01(\t\"h\n\x05Route\x12\x10\n\x08\x65ndpoint\x18\x01 \x01(\t\x12\x0e\n\x06weight\x18\x02 \x01(\r\x12\x0e\n\x06shadow\x18\x03 \x01(\x08\x12\x11\n\tvariation\x18\x04 \x01(\t\x12\x1a\n\x12request_timeout_ms\x18\x05 \x01(\x05*\xc4\x02\n\x11UnaryOperatorType\x12\x1f\n\x1bUNARY_OPERATOR_TYPE_INVALID\x10\x00\x12#\n\x1fUNARY_OPERATOR_TYPE_EXACT_MATCH\x10\x01\x12(\n$UNARY_OPERATOR_TYPE_SAFE_REGEX_MATCH\x10\x02\x12%\n!UNARY_OPERATOR_TYPE_PRESENT_MATCH\x10\x03\x12$\n UNARY_OPERATOR_TYPE_PREFIX_MATCH\x10\x04\x12$\n UNARY_OPERATOR_TYPE_SUFFIX_MATCH\x10\x05\x12&\n\"UNARY_OPERATOR_TYPE_CONTAINS_MATCH\x10\x06\x12$\n UNARY_OPERATOR_TYPE_STRING_MATCH\x10\x07*\\\n\x12\x42inaryOperatorType\x12 \n\x1c\x42INARY_OPERATOR_TYPE_INVALID\x10\x00\x12$\n BINARY_OPERATOR_TYPE_RANGE_MATCH\x10\x01\x42\x17\n\x13\x63om.qwak.traffic.v1P\x01\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'qwak.traffic.v1.traffic_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\023com.qwak.traffic.v1P\001'
  _globals['_UNARYOPERATORTYPE']._serialized_start=1027
  _globals['_UNARYOPERATORTYPE']._serialized_end=1351
  _globals['_BINARYOPERATORTYPE']._serialized_start=1353
  _globals['_BINARYOPERATORTYPE']._serialized_end=1445
  _globals['_MULTIPLEHTTPTRAFFIC']._serialized_start=50
  _globals['_MULTIPLEHTTPTRAFFIC']._serialized_end=124
  _globals['_HTTPTRAFFIC']._serialized_start=126
  _globals['_HTTPTRAFFIC']._serialized_end=252
  _globals['_ROUTEMATCH']._serialized_start=254
  _globals['_ROUTEMATCH']._serialized_end=361
  _globals['_MATCH']._serialized_start=363
  _globals['_MATCH']._serialized_end=432
  _globals['_HEADERMATCH']._serialized_start=434
  _globals['_HEADERMATCH']._serialized_end=529
  _globals['_HEADERCONDITION']._serialized_start=532
  _globals['_HEADERCONDITION']._serialized_end=696
  _globals['_HEADERUNARYCONDITION']._serialized_start=698
  _globals['_HEADERUNARYCONDITION']._serialized_end=791
  _globals['_HEADERBINARYCONDITION']._serialized_start=793
  _globals['_HEADERBINARYCONDITION']._serialized_end=918
  _globals['_ROUTE']._serialized_start=920
  _globals['_ROUTE']._serialized_end=1024
# @@protoc_insertion_point(module_scope)
