"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import qwak.execution.v1.state.execution_state_pb2
import qwak.execution.v1.state.featureset_state_pb2
import sys

if sys.version_info >= (3, 8):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

class GetFeaturesetStateByIdRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    FEATURESET_ID_FIELD_NUMBER: builtins.int
    featureset_id: builtins.str
    def __init__(
        self,
        *,
        featureset_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["featureset_id", b"featureset_id"]) -> None: ...

global___GetFeaturesetStateByIdRequest = GetFeaturesetStateByIdRequest

class GetFeaturesetStateByIdResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    FEATURESET_STATE_FIELD_NUMBER: builtins.int
    @property
    def featureset_state(self) -> qwak.execution.v1.state.featureset_state_pb2.FeaturesetState: ...
    def __init__(
        self,
        *,
        featureset_state: qwak.execution.v1.state.featureset_state_pb2.FeaturesetState | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["featureset_state", b"featureset_state"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["featureset_state", b"featureset_state"]) -> None: ...

global___GetFeaturesetStateByIdResponse = GetFeaturesetStateByIdResponse

class GetFeaturesetStateByNameRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    FEATURESET_NAME_FIELD_NUMBER: builtins.int
    featureset_name: builtins.str
    def __init__(
        self,
        *,
        featureset_name: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["featureset_name", b"featureset_name"]) -> None: ...

global___GetFeaturesetStateByNameRequest = GetFeaturesetStateByNameRequest

class GetFeaturesetStateByNameResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    FEATURESET_STATE_FIELD_NUMBER: builtins.int
    @property
    def featureset_state(self) -> qwak.execution.v1.state.featureset_state_pb2.FeaturesetState: ...
    def __init__(
        self,
        *,
        featureset_state: qwak.execution.v1.state.featureset_state_pb2.FeaturesetState | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["featureset_state", b"featureset_state"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["featureset_state", b"featureset_state"]) -> None: ...

global___GetFeaturesetStateByNameResponse = GetFeaturesetStateByNameResponse

class GetMultiFeaturesetStateByIdsRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    FEATURESET_IDS_FIELD_NUMBER: builtins.int
    @property
    def featureset_ids(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    def __init__(
        self,
        *,
        featureset_ids: collections.abc.Iterable[builtins.str] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["featureset_ids", b"featureset_ids"]) -> None: ...

global___GetMultiFeaturesetStateByIdsRequest = GetMultiFeaturesetStateByIdsRequest

class GetMultiFeaturesetStateByIdsResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    FEATURESET_STATES_FIELD_NUMBER: builtins.int
    @property
    def featureset_states(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[qwak.execution.v1.state.featureset_state_pb2.FeaturesetState]: ...
    def __init__(
        self,
        *,
        featureset_states: collections.abc.Iterable[qwak.execution.v1.state.featureset_state_pb2.FeaturesetState] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["featureset_states", b"featureset_states"]) -> None: ...

global___GetMultiFeaturesetStateByIdsResponse = GetMultiFeaturesetStateByIdsResponse

class GetMultiFeaturesetStateByNameRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    FEATURESET_NAME_FIELD_NUMBER: builtins.int
    @property
    def featureset_name(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    def __init__(
        self,
        *,
        featureset_name: collections.abc.Iterable[builtins.str] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["featureset_name", b"featureset_name"]) -> None: ...

global___GetMultiFeaturesetStateByNameRequest = GetMultiFeaturesetStateByNameRequest

class GetMultiFeaturesetStateByNameResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    FEATURESET_STATE_FIELD_NUMBER: builtins.int
    @property
    def featureset_state(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[qwak.execution.v1.state.featureset_state_pb2.FeaturesetState]: ...
    def __init__(
        self,
        *,
        featureset_state: collections.abc.Iterable[qwak.execution.v1.state.featureset_state_pb2.FeaturesetState] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["featureset_state", b"featureset_state"]) -> None: ...

global___GetMultiFeaturesetStateByNameResponse = GetMultiFeaturesetStateByNameResponse

class UpdateMultiExecutionStateRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    EXECUTION_STATE_FIELD_NUMBER: builtins.int
    @property
    def execution_state(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[qwak.execution.v1.state.execution_state_pb2.ExecutionState]: ...
    def __init__(
        self,
        *,
        execution_state: collections.abc.Iterable[qwak.execution.v1.state.execution_state_pb2.ExecutionState] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["execution_state", b"execution_state"]) -> None: ...

global___UpdateMultiExecutionStateRequest = UpdateMultiExecutionStateRequest

class UpdateMultiExecutionStateResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    def __init__(
        self,
    ) -> None: ...

global___UpdateMultiExecutionStateResponse = UpdateMultiExecutionStateResponse

class DeleteFeaturesetStateByIdRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    FEATURESET_ID_FIELD_NUMBER: builtins.int
    featureset_id: builtins.str
    def __init__(
        self,
        *,
        featureset_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["featureset_id", b"featureset_id"]) -> None: ...

global___DeleteFeaturesetStateByIdRequest = DeleteFeaturesetStateByIdRequest

class DeleteFeaturesetStateByIdResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NUM_DELETED_RECORDS_FIELD_NUMBER: builtins.int
    num_deleted_records: builtins.int
    """number of deleted records"""
    def __init__(
        self,
        *,
        num_deleted_records: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["num_deleted_records", b"num_deleted_records"]) -> None: ...

global___DeleteFeaturesetStateByIdResponse = DeleteFeaturesetStateByIdResponse
