# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from _qwak_proto.qwak.self_service.account.v0 import account_membership_service_pb2 as qwak_dot_self__service_dot_account_dot_v0_dot_account__membership__service__pb2


class AccountMembershipServiceStub(object):
    """Missing associated documentation comment in .proto file."""

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.ListAccountUserProfiles = channel.unary_unary(
                '/qwak.self_service.account.v0.AccountMembershipService/ListAccountUserProfiles',
                request_serializer=qwak_dot_self__service_dot_account_dot_v0_dot_account__membership__service__pb2.ListAccountUserProfilesRequest.SerializeToString,
                response_deserializer=qwak_dot_self__service_dot_account_dot_v0_dot_account__membership__service__pb2.ListAccountUserProfilesResponse.FromString,
                )
        self.UpdateUserRole = channel.unary_unary(
                '/qwak.self_service.account.v0.AccountMembershipService/UpdateUserRole',
                request_serializer=qwak_dot_self__service_dot_account_dot_v0_dot_account__membership__service__pb2.UpdateUserRoleRequest.SerializeToString,
                response_deserializer=qwak_dot_self__service_dot_account_dot_v0_dot_account__membership__service__pb2.UpdateUserRoleResponse.FromString,
                )
        self.UpdateUserAssignedEnvironments = channel.unary_unary(
                '/qwak.self_service.account.v0.AccountMembershipService/UpdateUserAssignedEnvironments',
                request_serializer=qwak_dot_self__service_dot_account_dot_v0_dot_account__membership__service__pb2.UpdateUserAssignedEnvironmentsRequest.SerializeToString,
                response_deserializer=qwak_dot_self__service_dot_account_dot_v0_dot_account__membership__service__pb2.UpdateUserAssignedEnvironmentsResponse.FromString,
                )
        self.RemoveUserFromAccount = channel.unary_unary(
                '/qwak.self_service.account.v0.AccountMembershipService/RemoveUserFromAccount',
                request_serializer=qwak_dot_self__service_dot_account_dot_v0_dot_account__membership__service__pb2.RemoveUserFromAccountRequest.SerializeToString,
                response_deserializer=qwak_dot_self__service_dot_account_dot_v0_dot_account__membership__service__pb2.RemoveUserFromAccountResponse.FromString,
                )
        self.InviteToJoinAccount = channel.unary_unary(
                '/qwak.self_service.account.v0.AccountMembershipService/InviteToJoinAccount',
                request_serializer=qwak_dot_self__service_dot_account_dot_v0_dot_account__membership__service__pb2.InviteToJoinAccountRequest.SerializeToString,
                response_deserializer=qwak_dot_self__service_dot_account_dot_v0_dot_account__membership__service__pb2.InviteToJoinAccountResponse.FromString,
                )
        self.UpdateInvitation = channel.unary_unary(
                '/qwak.self_service.account.v0.AccountMembershipService/UpdateInvitation',
                request_serializer=qwak_dot_self__service_dot_account_dot_v0_dot_account__membership__service__pb2.UpdateInvitationRequest.SerializeToString,
                response_deserializer=qwak_dot_self__service_dot_account_dot_v0_dot_account__membership__service__pb2.UpdateInvitationResponse.FromString,
                )
        self.AcceptInvitation = channel.unary_unary(
                '/qwak.self_service.account.v0.AccountMembershipService/AcceptInvitation',
                request_serializer=qwak_dot_self__service_dot_account_dot_v0_dot_account__membership__service__pb2.AcceptInvitationRequest.SerializeToString,
                response_deserializer=qwak_dot_self__service_dot_account_dot_v0_dot_account__membership__service__pb2.AcceptInvitationResponse.FromString,
                )
        self.CancelJoiningInvitation = channel.unary_unary(
                '/qwak.self_service.account.v0.AccountMembershipService/CancelJoiningInvitation',
                request_serializer=qwak_dot_self__service_dot_account_dot_v0_dot_account__membership__service__pb2.CancelJoiningInvitationRequest.SerializeToString,
                response_deserializer=qwak_dot_self__service_dot_account_dot_v0_dot_account__membership__service__pb2.CancelJoiningInvitationResponse.FromString,
                )
        self.ListAccountInvitations = channel.unary_unary(
                '/qwak.self_service.account.v0.AccountMembershipService/ListAccountInvitations',
                request_serializer=qwak_dot_self__service_dot_account_dot_v0_dot_account__membership__service__pb2.ListAccountInvitationsRequest.SerializeToString,
                response_deserializer=qwak_dot_self__service_dot_account_dot_v0_dot_account__membership__service__pb2.ListAccountInvitationsResponse.FromString,
                )
        self.ListUserInvitations = channel.unary_unary(
                '/qwak.self_service.account.v0.AccountMembershipService/ListUserInvitations',
                request_serializer=qwak_dot_self__service_dot_account_dot_v0_dot_account__membership__service__pb2.ListUserInvitationsRequest.SerializeToString,
                response_deserializer=qwak_dot_self__service_dot_account_dot_v0_dot_account__membership__service__pb2.ListUserInvitationsResponse.FromString,
                )
        self.ListUserMemberships = channel.unary_unary(
                '/qwak.self_service.account.v0.AccountMembershipService/ListUserMemberships',
                request_serializer=qwak_dot_self__service_dot_account_dot_v0_dot_account__membership__service__pb2.ListUserMembershipsRequest.SerializeToString,
                response_deserializer=qwak_dot_self__service_dot_account_dot_v0_dot_account__membership__service__pb2.ListUserMembershipsResponse.FromString,
                )


class AccountMembershipServiceServicer(object):
    """Missing associated documentation comment in .proto file."""

    def ListAccountUserProfiles(self, request, context):
        """List account users
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def UpdateUserRole(self, request, context):
        """Update user role
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def UpdateUserAssignedEnvironments(self, request, context):
        """Update user assigned environments
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def RemoveUserFromAccount(self, request, context):
        """Remove user from account
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def InviteToJoinAccount(self, request, context):
        """Invite new member to join account
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def UpdateInvitation(self, request, context):
        """Update invitation
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def AcceptInvitation(self, request, context):
        """Accept invitation
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def CancelJoiningInvitation(self, request, context):
        """Cancel a sent invitation
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ListAccountInvitations(self, request, context):
        """List account invitation, for getting invitation to join the account
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ListUserInvitations(self, request, context):
        """List user invitation, for getting invitation of the authenticated user
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ListUserMemberships(self, request, context):
        """List user membership, for getting invitation of the authenticated user
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_AccountMembershipServiceServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'ListAccountUserProfiles': grpc.unary_unary_rpc_method_handler(
                    servicer.ListAccountUserProfiles,
                    request_deserializer=qwak_dot_self__service_dot_account_dot_v0_dot_account__membership__service__pb2.ListAccountUserProfilesRequest.FromString,
                    response_serializer=qwak_dot_self__service_dot_account_dot_v0_dot_account__membership__service__pb2.ListAccountUserProfilesResponse.SerializeToString,
            ),
            'UpdateUserRole': grpc.unary_unary_rpc_method_handler(
                    servicer.UpdateUserRole,
                    request_deserializer=qwak_dot_self__service_dot_account_dot_v0_dot_account__membership__service__pb2.UpdateUserRoleRequest.FromString,
                    response_serializer=qwak_dot_self__service_dot_account_dot_v0_dot_account__membership__service__pb2.UpdateUserRoleResponse.SerializeToString,
            ),
            'UpdateUserAssignedEnvironments': grpc.unary_unary_rpc_method_handler(
                    servicer.UpdateUserAssignedEnvironments,
                    request_deserializer=qwak_dot_self__service_dot_account_dot_v0_dot_account__membership__service__pb2.UpdateUserAssignedEnvironmentsRequest.FromString,
                    response_serializer=qwak_dot_self__service_dot_account_dot_v0_dot_account__membership__service__pb2.UpdateUserAssignedEnvironmentsResponse.SerializeToString,
            ),
            'RemoveUserFromAccount': grpc.unary_unary_rpc_method_handler(
                    servicer.RemoveUserFromAccount,
                    request_deserializer=qwak_dot_self__service_dot_account_dot_v0_dot_account__membership__service__pb2.RemoveUserFromAccountRequest.FromString,
                    response_serializer=qwak_dot_self__service_dot_account_dot_v0_dot_account__membership__service__pb2.RemoveUserFromAccountResponse.SerializeToString,
            ),
            'InviteToJoinAccount': grpc.unary_unary_rpc_method_handler(
                    servicer.InviteToJoinAccount,
                    request_deserializer=qwak_dot_self__service_dot_account_dot_v0_dot_account__membership__service__pb2.InviteToJoinAccountRequest.FromString,
                    response_serializer=qwak_dot_self__service_dot_account_dot_v0_dot_account__membership__service__pb2.InviteToJoinAccountResponse.SerializeToString,
            ),
            'UpdateInvitation': grpc.unary_unary_rpc_method_handler(
                    servicer.UpdateInvitation,
                    request_deserializer=qwak_dot_self__service_dot_account_dot_v0_dot_account__membership__service__pb2.UpdateInvitationRequest.FromString,
                    response_serializer=qwak_dot_self__service_dot_account_dot_v0_dot_account__membership__service__pb2.UpdateInvitationResponse.SerializeToString,
            ),
            'AcceptInvitation': grpc.unary_unary_rpc_method_handler(
                    servicer.AcceptInvitation,
                    request_deserializer=qwak_dot_self__service_dot_account_dot_v0_dot_account__membership__service__pb2.AcceptInvitationRequest.FromString,
                    response_serializer=qwak_dot_self__service_dot_account_dot_v0_dot_account__membership__service__pb2.AcceptInvitationResponse.SerializeToString,
            ),
            'CancelJoiningInvitation': grpc.unary_unary_rpc_method_handler(
                    servicer.CancelJoiningInvitation,
                    request_deserializer=qwak_dot_self__service_dot_account_dot_v0_dot_account__membership__service__pb2.CancelJoiningInvitationRequest.FromString,
                    response_serializer=qwak_dot_self__service_dot_account_dot_v0_dot_account__membership__service__pb2.CancelJoiningInvitationResponse.SerializeToString,
            ),
            'ListAccountInvitations': grpc.unary_unary_rpc_method_handler(
                    servicer.ListAccountInvitations,
                    request_deserializer=qwak_dot_self__service_dot_account_dot_v0_dot_account__membership__service__pb2.ListAccountInvitationsRequest.FromString,
                    response_serializer=qwak_dot_self__service_dot_account_dot_v0_dot_account__membership__service__pb2.ListAccountInvitationsResponse.SerializeToString,
            ),
            'ListUserInvitations': grpc.unary_unary_rpc_method_handler(
                    servicer.ListUserInvitations,
                    request_deserializer=qwak_dot_self__service_dot_account_dot_v0_dot_account__membership__service__pb2.ListUserInvitationsRequest.FromString,
                    response_serializer=qwak_dot_self__service_dot_account_dot_v0_dot_account__membership__service__pb2.ListUserInvitationsResponse.SerializeToString,
            ),
            'ListUserMemberships': grpc.unary_unary_rpc_method_handler(
                    servicer.ListUserMemberships,
                    request_deserializer=qwak_dot_self__service_dot_account_dot_v0_dot_account__membership__service__pb2.ListUserMembershipsRequest.FromString,
                    response_serializer=qwak_dot_self__service_dot_account_dot_v0_dot_account__membership__service__pb2.ListUserMembershipsResponse.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'qwak.self_service.account.v0.AccountMembershipService', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class AccountMembershipService(object):
    """Missing associated documentation comment in .proto file."""

    @staticmethod
    def ListAccountUserProfiles(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/qwak.self_service.account.v0.AccountMembershipService/ListAccountUserProfiles',
            qwak_dot_self__service_dot_account_dot_v0_dot_account__membership__service__pb2.ListAccountUserProfilesRequest.SerializeToString,
            qwak_dot_self__service_dot_account_dot_v0_dot_account__membership__service__pb2.ListAccountUserProfilesResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def UpdateUserRole(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/qwak.self_service.account.v0.AccountMembershipService/UpdateUserRole',
            qwak_dot_self__service_dot_account_dot_v0_dot_account__membership__service__pb2.UpdateUserRoleRequest.SerializeToString,
            qwak_dot_self__service_dot_account_dot_v0_dot_account__membership__service__pb2.UpdateUserRoleResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def UpdateUserAssignedEnvironments(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/qwak.self_service.account.v0.AccountMembershipService/UpdateUserAssignedEnvironments',
            qwak_dot_self__service_dot_account_dot_v0_dot_account__membership__service__pb2.UpdateUserAssignedEnvironmentsRequest.SerializeToString,
            qwak_dot_self__service_dot_account_dot_v0_dot_account__membership__service__pb2.UpdateUserAssignedEnvironmentsResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def RemoveUserFromAccount(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/qwak.self_service.account.v0.AccountMembershipService/RemoveUserFromAccount',
            qwak_dot_self__service_dot_account_dot_v0_dot_account__membership__service__pb2.RemoveUserFromAccountRequest.SerializeToString,
            qwak_dot_self__service_dot_account_dot_v0_dot_account__membership__service__pb2.RemoveUserFromAccountResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def InviteToJoinAccount(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/qwak.self_service.account.v0.AccountMembershipService/InviteToJoinAccount',
            qwak_dot_self__service_dot_account_dot_v0_dot_account__membership__service__pb2.InviteToJoinAccountRequest.SerializeToString,
            qwak_dot_self__service_dot_account_dot_v0_dot_account__membership__service__pb2.InviteToJoinAccountResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def UpdateInvitation(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/qwak.self_service.account.v0.AccountMembershipService/UpdateInvitation',
            qwak_dot_self__service_dot_account_dot_v0_dot_account__membership__service__pb2.UpdateInvitationRequest.SerializeToString,
            qwak_dot_self__service_dot_account_dot_v0_dot_account__membership__service__pb2.UpdateInvitationResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def AcceptInvitation(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/qwak.self_service.account.v0.AccountMembershipService/AcceptInvitation',
            qwak_dot_self__service_dot_account_dot_v0_dot_account__membership__service__pb2.AcceptInvitationRequest.SerializeToString,
            qwak_dot_self__service_dot_account_dot_v0_dot_account__membership__service__pb2.AcceptInvitationResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def CancelJoiningInvitation(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/qwak.self_service.account.v0.AccountMembershipService/CancelJoiningInvitation',
            qwak_dot_self__service_dot_account_dot_v0_dot_account__membership__service__pb2.CancelJoiningInvitationRequest.SerializeToString,
            qwak_dot_self__service_dot_account_dot_v0_dot_account__membership__service__pb2.CancelJoiningInvitationResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ListAccountInvitations(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/qwak.self_service.account.v0.AccountMembershipService/ListAccountInvitations',
            qwak_dot_self__service_dot_account_dot_v0_dot_account__membership__service__pb2.ListAccountInvitationsRequest.SerializeToString,
            qwak_dot_self__service_dot_account_dot_v0_dot_account__membership__service__pb2.ListAccountInvitationsResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ListUserInvitations(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/qwak.self_service.account.v0.AccountMembershipService/ListUserInvitations',
            qwak_dot_self__service_dot_account_dot_v0_dot_account__membership__service__pb2.ListUserInvitationsRequest.SerializeToString,
            qwak_dot_self__service_dot_account_dot_v0_dot_account__membership__service__pb2.ListUserInvitationsResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ListUserMemberships(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/qwak.self_service.account.v0.AccountMembershipService/ListUserMemberships',
            qwak_dot_self__service_dot_account_dot_v0_dot_account__membership__service__pb2.ListUserMembershipsRequest.SerializeToString,
            qwak_dot_self__service_dot_account_dot_v0_dot_account__membership__service__pb2.ListUserMembershipsResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)
