# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from _qwak_proto.qwak.administration.account.v1 import account_service_pb2 as qwak_dot_administration_dot_account_dot_v1_dot_account__service__pb2


class AccountServiceStub(object):
    """Missing associated documentation comment in .proto file."""

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.CreateAccount = channel.unary_unary(
                '/qwak.administration.account.v1.AccountService/CreateAccount',
                request_serializer=qwak_dot_administration_dot_account_dot_v1_dot_account__service__pb2.CreateAccountRequest.SerializeToString,
                response_deserializer=qwak_dot_administration_dot_account_dot_v1_dot_account__service__pb2.CreateAccountResponse.FromString,
                )
        self.GetAccount = channel.unary_unary(
                '/qwak.administration.account.v1.AccountService/GetAccount',
                request_serializer=qwak_dot_administration_dot_account_dot_v1_dot_account__service__pb2.GetAccountRequest.SerializeToString,
                response_deserializer=qwak_dot_administration_dot_account_dot_v1_dot_account__service__pb2.GetAccountResponse.FromString,
                )
        self.ListAccounts = channel.unary_unary(
                '/qwak.administration.account.v1.AccountService/ListAccounts',
                request_serializer=qwak_dot_administration_dot_account_dot_v1_dot_account__service__pb2.ListAccountsRequest.SerializeToString,
                response_deserializer=qwak_dot_administration_dot_account_dot_v1_dot_account__service__pb2.ListAccountsResponse.FromString,
                )
        self.UpdateAccount = channel.unary_unary(
                '/qwak.administration.account.v1.AccountService/UpdateAccount',
                request_serializer=qwak_dot_administration_dot_account_dot_v1_dot_account__service__pb2.UpdateAccountRequest.SerializeToString,
                response_deserializer=qwak_dot_administration_dot_account_dot_v1_dot_account__service__pb2.UpdateAccountResponse.FromString,
                )
        self.UpdateAccountPreferences = channel.unary_unary(
                '/qwak.administration.account.v1.AccountService/UpdateAccountPreferences',
                request_serializer=qwak_dot_administration_dot_account_dot_v1_dot_account__service__pb2.UpdateAccountPreferencesRequest.SerializeToString,
                response_deserializer=qwak_dot_administration_dot_account_dot_v1_dot_account__service__pb2.UpdateAccountPreferencesResponse.FromString,
                )
        self.UpdateAccountAcceptedTerms = channel.unary_unary(
                '/qwak.administration.account.v1.AccountService/UpdateAccountAcceptedTerms',
                request_serializer=qwak_dot_administration_dot_account_dot_v1_dot_account__service__pb2.UpdateAccountAcceptedTermsRequest.SerializeToString,
                response_deserializer=qwak_dot_administration_dot_account_dot_v1_dot_account__service__pb2.UpdateAccountAcceptedTermsResponse.FromString,
                )
        self.AddAutoBinding = channel.unary_unary(
                '/qwak.administration.account.v1.AccountService/AddAutoBinding',
                request_serializer=qwak_dot_administration_dot_account_dot_v1_dot_account__service__pb2.AddAutoBindingRequest.SerializeToString,
                response_deserializer=qwak_dot_administration_dot_account_dot_v1_dot_account__service__pb2.AddAutoBindingResponse.FromString,
                )
        self.RemoveAutoBinding = channel.unary_unary(
                '/qwak.administration.account.v1.AccountService/RemoveAutoBinding',
                request_serializer=qwak_dot_administration_dot_account_dot_v1_dot_account__service__pb2.RemoveAutoBindingRequest.SerializeToString,
                response_deserializer=qwak_dot_administration_dot_account_dot_v1_dot_account__service__pb2.RemoveAutoBindingResponse.FromString,
                )
        self.GetAccountBrief = channel.unary_unary(
                '/qwak.administration.account.v1.AccountService/GetAccountBrief',
                request_serializer=qwak_dot_administration_dot_account_dot_v1_dot_account__service__pb2.GetAccountBriefRequest.SerializeToString,
                response_deserializer=qwak_dot_administration_dot_account_dot_v1_dot_account__service__pb2.GetAccountBriefResponse.FromString,
                )


class AccountServiceServicer(object):
    """Missing associated documentation comment in .proto file."""

    def CreateAccount(self, request, context):
        """Create account
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetAccount(self, request, context):
        """Get a account
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ListAccounts(self, request, context):
        """List accounts
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def UpdateAccount(self, request, context):
        """Update account
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def UpdateAccountPreferences(self, request, context):
        """Update account preferences
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def UpdateAccountAcceptedTerms(self, request, context):
        """Update account preferences
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def AddAutoBinding(self, request, context):
        """Add hostname to auto-bind to account
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def RemoveAutoBinding(self, request, context):
        """Remove hostname to auto-bind to account
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetAccountBrief(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_AccountServiceServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'CreateAccount': grpc.unary_unary_rpc_method_handler(
                    servicer.CreateAccount,
                    request_deserializer=qwak_dot_administration_dot_account_dot_v1_dot_account__service__pb2.CreateAccountRequest.FromString,
                    response_serializer=qwak_dot_administration_dot_account_dot_v1_dot_account__service__pb2.CreateAccountResponse.SerializeToString,
            ),
            'GetAccount': grpc.unary_unary_rpc_method_handler(
                    servicer.GetAccount,
                    request_deserializer=qwak_dot_administration_dot_account_dot_v1_dot_account__service__pb2.GetAccountRequest.FromString,
                    response_serializer=qwak_dot_administration_dot_account_dot_v1_dot_account__service__pb2.GetAccountResponse.SerializeToString,
            ),
            'ListAccounts': grpc.unary_unary_rpc_method_handler(
                    servicer.ListAccounts,
                    request_deserializer=qwak_dot_administration_dot_account_dot_v1_dot_account__service__pb2.ListAccountsRequest.FromString,
                    response_serializer=qwak_dot_administration_dot_account_dot_v1_dot_account__service__pb2.ListAccountsResponse.SerializeToString,
            ),
            'UpdateAccount': grpc.unary_unary_rpc_method_handler(
                    servicer.UpdateAccount,
                    request_deserializer=qwak_dot_administration_dot_account_dot_v1_dot_account__service__pb2.UpdateAccountRequest.FromString,
                    response_serializer=qwak_dot_administration_dot_account_dot_v1_dot_account__service__pb2.UpdateAccountResponse.SerializeToString,
            ),
            'UpdateAccountPreferences': grpc.unary_unary_rpc_method_handler(
                    servicer.UpdateAccountPreferences,
                    request_deserializer=qwak_dot_administration_dot_account_dot_v1_dot_account__service__pb2.UpdateAccountPreferencesRequest.FromString,
                    response_serializer=qwak_dot_administration_dot_account_dot_v1_dot_account__service__pb2.UpdateAccountPreferencesResponse.SerializeToString,
            ),
            'UpdateAccountAcceptedTerms': grpc.unary_unary_rpc_method_handler(
                    servicer.UpdateAccountAcceptedTerms,
                    request_deserializer=qwak_dot_administration_dot_account_dot_v1_dot_account__service__pb2.UpdateAccountAcceptedTermsRequest.FromString,
                    response_serializer=qwak_dot_administration_dot_account_dot_v1_dot_account__service__pb2.UpdateAccountAcceptedTermsResponse.SerializeToString,
            ),
            'AddAutoBinding': grpc.unary_unary_rpc_method_handler(
                    servicer.AddAutoBinding,
                    request_deserializer=qwak_dot_administration_dot_account_dot_v1_dot_account__service__pb2.AddAutoBindingRequest.FromString,
                    response_serializer=qwak_dot_administration_dot_account_dot_v1_dot_account__service__pb2.AddAutoBindingResponse.SerializeToString,
            ),
            'RemoveAutoBinding': grpc.unary_unary_rpc_method_handler(
                    servicer.RemoveAutoBinding,
                    request_deserializer=qwak_dot_administration_dot_account_dot_v1_dot_account__service__pb2.RemoveAutoBindingRequest.FromString,
                    response_serializer=qwak_dot_administration_dot_account_dot_v1_dot_account__service__pb2.RemoveAutoBindingResponse.SerializeToString,
            ),
            'GetAccountBrief': grpc.unary_unary_rpc_method_handler(
                    servicer.GetAccountBrief,
                    request_deserializer=qwak_dot_administration_dot_account_dot_v1_dot_account__service__pb2.GetAccountBriefRequest.FromString,
                    response_serializer=qwak_dot_administration_dot_account_dot_v1_dot_account__service__pb2.GetAccountBriefResponse.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'qwak.administration.account.v1.AccountService', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class AccountService(object):
    """Missing associated documentation comment in .proto file."""

    @staticmethod
    def CreateAccount(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/qwak.administration.account.v1.AccountService/CreateAccount',
            qwak_dot_administration_dot_account_dot_v1_dot_account__service__pb2.CreateAccountRequest.SerializeToString,
            qwak_dot_administration_dot_account_dot_v1_dot_account__service__pb2.CreateAccountResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetAccount(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/qwak.administration.account.v1.AccountService/GetAccount',
            qwak_dot_administration_dot_account_dot_v1_dot_account__service__pb2.GetAccountRequest.SerializeToString,
            qwak_dot_administration_dot_account_dot_v1_dot_account__service__pb2.GetAccountResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ListAccounts(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/qwak.administration.account.v1.AccountService/ListAccounts',
            qwak_dot_administration_dot_account_dot_v1_dot_account__service__pb2.ListAccountsRequest.SerializeToString,
            qwak_dot_administration_dot_account_dot_v1_dot_account__service__pb2.ListAccountsResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def UpdateAccount(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/qwak.administration.account.v1.AccountService/UpdateAccount',
            qwak_dot_administration_dot_account_dot_v1_dot_account__service__pb2.UpdateAccountRequest.SerializeToString,
            qwak_dot_administration_dot_account_dot_v1_dot_account__service__pb2.UpdateAccountResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def UpdateAccountPreferences(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/qwak.administration.account.v1.AccountService/UpdateAccountPreferences',
            qwak_dot_administration_dot_account_dot_v1_dot_account__service__pb2.UpdateAccountPreferencesRequest.SerializeToString,
            qwak_dot_administration_dot_account_dot_v1_dot_account__service__pb2.UpdateAccountPreferencesResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def UpdateAccountAcceptedTerms(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/qwak.administration.account.v1.AccountService/UpdateAccountAcceptedTerms',
            qwak_dot_administration_dot_account_dot_v1_dot_account__service__pb2.UpdateAccountAcceptedTermsRequest.SerializeToString,
            qwak_dot_administration_dot_account_dot_v1_dot_account__service__pb2.UpdateAccountAcceptedTermsResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def AddAutoBinding(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/qwak.administration.account.v1.AccountService/AddAutoBinding',
            qwak_dot_administration_dot_account_dot_v1_dot_account__service__pb2.AddAutoBindingRequest.SerializeToString,
            qwak_dot_administration_dot_account_dot_v1_dot_account__service__pb2.AddAutoBindingResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def RemoveAutoBinding(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/qwak.administration.account.v1.AccountService/RemoveAutoBinding',
            qwak_dot_administration_dot_account_dot_v1_dot_account__service__pb2.RemoveAutoBindingRequest.SerializeToString,
            qwak_dot_administration_dot_account_dot_v1_dot_account__service__pb2.RemoveAutoBindingResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetAccountBrief(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/qwak.administration.account.v1.AccountService/GetAccountBrief',
            qwak_dot_administration_dot_account_dot_v1_dot_account__service__pb2.GetAccountBriefRequest.SerializeToString,
            qwak_dot_administration_dot_account_dot_v1_dot_account__service__pb2.GetAccountBriefResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)
