# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: qwak/feature_store/serving/metadata.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from _qwak_proto.qwak.feature_store.features import feature_set_types_pb2 as qwak_dot_feature__store_dot_features_dot_feature__set__types__pb2
from _qwak_proto.qwak.feature_store.entities import entity_pb2 as qwak_dot_feature__store_dot_entities_dot_entity__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n)qwak/feature_store/serving/metadata.proto\x12*com.qwak.ai.feature.store.serving.metadata\x1a\x33qwak/feature_store/features/feature_set_types.proto\x1a(qwak/feature_store/entities/entity.proto\"\xb0\x02\n&StreamingAggregationFeaturesetMetadata\x12\x16\n\x0e\x65nvironment_id\x18\x01 \x01(\t\x12\x17\n\x0f\x66\x65\x61tureset_name\x18\x02 \x01(\t\x12\x15\n\rfeatureset_id\x18\x03 \x01(\t\x12\x65\n streaming_aggregation_featureset\x18\x04 \x01(\x0b\x32;.qwak.feature.store.features.StreamingAggregationFeatureSet\x12=\n\x06\x65ntity\x18\x05 \x01(\x0b\x32-.qwak.feature.store.entities.EntityDefinition\x12\x18\n\x10\x61vro_schema_json\x18\x06 \x01(\t\"\x8e\x02\n\x19\x42\x61tchFeaturesetV1Metadata\x12\x16\n\x0e\x65nvironment_id\x18\x01 \x01(\t\x12\x17\n\x0f\x66\x65\x61tureset_name\x18\x02 \x01(\t\x12\x15\n\rfeatureset_id\x18\x03 \x01(\t\x12\x1d\n\x15qwak_protocol_version\x18\x04 \x01(\x05\x12K\n\x13\x62\x61tch_featureset_v1\x18\x05 \x01(\x0b\x32..qwak.feature.store.features.BatchFeatureSetV1\x12=\n\x06\x65ntity\x18\x06 \x01(\x0b\x32-.qwak.feature.store.entities.EntityDefinition\"\x9a\x02\n\x1dStreamingFeaturesetV1Metadata\x12\x16\n\x0e\x65nvironment_id\x18\x01 \x01(\t\x12\x17\n\x0f\x66\x65\x61tureset_name\x18\x02 \x01(\t\x12\x15\n\rfeatureset_id\x18\x03 \x01(\t\x12\x1d\n\x15qwak_protocol_version\x18\x04 \x01(\x05\x12S\n\x17streaming_featureset_v1\x18\x05 \x01(\x0b\x32\x32.qwak.feature.store.features.StreamingFeatureSetV1\x12=\n\x06\x65ntity\x18\x06 \x01(\x0b\x32-.qwak.feature.store.entities.EntityDefinition\"\x7f\n\x1a\x46\x65\x61turesetMemoryUsageStats\x12\x16\n\x0e\x65nvironment_id\x18\x01 \x01(\t\x12\x15\n\rfeatureset_id\x18\x02 \x01(\t\x12\x17\n\x0f\x66\x65\x61tureset_name\x18\x03 \x01(\t\x12\x19\n\x11online_used_bytes\x18\x04 \x01(\x03\x42,\n*com.qwak.ai.feature.store.serving.metadatab\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'qwak.feature_store.serving.metadata_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n*com.qwak.ai.feature.store.serving.metadata'
  _globals['_STREAMINGAGGREGATIONFEATURESETMETADATA']._serialized_start=185
  _globals['_STREAMINGAGGREGATIONFEATURESETMETADATA']._serialized_end=489
  _globals['_BATCHFEATURESETV1METADATA']._serialized_start=492
  _globals['_BATCHFEATURESETV1METADATA']._serialized_end=762
  _globals['_STREAMINGFEATURESETV1METADATA']._serialized_start=765
  _globals['_STREAMINGFEATURESETV1METADATA']._serialized_end=1047
  _globals['_FEATURESETMEMORYUSAGESTATS']._serialized_start=1049
  _globals['_FEATURESETMEMORYUSAGESTATS']._serialized_end=1176
# @@protoc_insertion_point(module_scope)
