# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from _qwak_proto.qwak.workspace import workspace_service_pb2 as qwak_dot_workspace_dot_workspace__service__pb2


class WorkspaceManagementServiceStub(object):
    """Missing associated documentation comment in .proto file."""

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.CreateWorkspace = channel.unary_unary(
                '/qwak.workspace.management.WorkspaceManagementService/CreateWorkspace',
                request_serializer=qwak_dot_workspace_dot_workspace__service__pb2.CreateWorkspaceRequest.SerializeToString,
                response_deserializer=qwak_dot_workspace_dot_workspace__service__pb2.CreateWorkspaceResponse.FromString,
                )
        self.UpdateWorkspace = channel.unary_unary(
                '/qwak.workspace.management.WorkspaceManagementService/UpdateWorkspace',
                request_serializer=qwak_dot_workspace_dot_workspace__service__pb2.UpdateWorkspaceRequest.SerializeToString,
                response_deserializer=qwak_dot_workspace_dot_workspace__service__pb2.UpdateWorkspaceResponse.FromString,
                )
        self.DeployWorkspace = channel.unary_unary(
                '/qwak.workspace.management.WorkspaceManagementService/DeployWorkspace',
                request_serializer=qwak_dot_workspace_dot_workspace__service__pb2.DeployWorkspaceRequest.SerializeToString,
                response_deserializer=qwak_dot_workspace_dot_workspace__service__pb2.DeployWorkspaceResponse.FromString,
                )
        self.UndeployWorkspace = channel.unary_unary(
                '/qwak.workspace.management.WorkspaceManagementService/UndeployWorkspace',
                request_serializer=qwak_dot_workspace_dot_workspace__service__pb2.UndeployWorkspaceRequest.SerializeToString,
                response_deserializer=qwak_dot_workspace_dot_workspace__service__pb2.UndeployWorkspaceResponse.FromString,
                )
        self.ListWorkspaces = channel.unary_unary(
                '/qwak.workspace.management.WorkspaceManagementService/ListWorkspaces',
                request_serializer=qwak_dot_workspace_dot_workspace__service__pb2.ListWorkspacesRequest.SerializeToString,
                response_deserializer=qwak_dot_workspace_dot_workspace__service__pb2.ListWorkspacesResponse.FromString,
                )
        self.GetWorkspaceById = channel.unary_unary(
                '/qwak.workspace.management.WorkspaceManagementService/GetWorkspaceById',
                request_serializer=qwak_dot_workspace_dot_workspace__service__pb2.GetWorkspaceByIdRequest.SerializeToString,
                response_deserializer=qwak_dot_workspace_dot_workspace__service__pb2.GetWorkspaceByIdResponse.FromString,
                )
        self.DeleteWorkspace = channel.unary_unary(
                '/qwak.workspace.management.WorkspaceManagementService/DeleteWorkspace',
                request_serializer=qwak_dot_workspace_dot_workspace__service__pb2.DeleteWorkspaceRequest.SerializeToString,
                response_deserializer=qwak_dot_workspace_dot_workspace__service__pb2.DeleteWorkspaceResponse.FromString,
                )
        self.UpdateWorkspaceStatusFromEdge = channel.unary_unary(
                '/qwak.workspace.management.WorkspaceManagementService/UpdateWorkspaceStatusFromEdge',
                request_serializer=qwak_dot_workspace_dot_workspace__service__pb2.UpdateWorkspaceStatusFromEdgeRequest.SerializeToString,
                response_deserializer=qwak_dot_workspace_dot_workspace__service__pb2.UpdateWorkspaceStatusFromEdgeResponse.FromString,
                )
        self.ListWorkspaceImages = channel.unary_unary(
                '/qwak.workspace.management.WorkspaceManagementService/ListWorkspaceImages',
                request_serializer=qwak_dot_workspace_dot_workspace__service__pb2.ListWorkspaceImagesRequest.SerializeToString,
                response_deserializer=qwak_dot_workspace_dot_workspace__service__pb2.ListWorkspaceImagesResponse.FromString,
                )
        self.RegisterWorkspaceTags = channel.unary_unary(
                '/qwak.workspace.management.WorkspaceManagementService/RegisterWorkspaceTags',
                request_serializer=qwak_dot_workspace_dot_workspace__service__pb2.RegisterWorkspaceTagRequest.SerializeToString,
                response_deserializer=qwak_dot_workspace_dot_workspace__service__pb2.RegisterWorkspaceTagResponse.FromString,
                )
        self.CountWorkspaces = channel.unary_unary(
                '/qwak.workspace.management.WorkspaceManagementService/CountWorkspaces',
                request_serializer=qwak_dot_workspace_dot_workspace__service__pb2.CountWorkspacesRequest.SerializeToString,
                response_deserializer=qwak_dot_workspace_dot_workspace__service__pb2.CountWorkspacesResponse.FromString,
                )
        self.GetDefaultWorkspaceValues = channel.unary_unary(
                '/qwak.workspace.management.WorkspaceManagementService/GetDefaultWorkspaceValues',
                request_serializer=qwak_dot_workspace_dot_workspace__service__pb2.GetDefaultWorkspaceValuesRequest.SerializeToString,
                response_deserializer=qwak_dot_workspace_dot_workspace__service__pb2.GetDefaultWorkspaceValuesResponse.FromString,
                )
        self.MarkBuildAsCopied = channel.unary_unary(
                '/qwak.workspace.management.WorkspaceManagementService/MarkBuildAsCopied',
                request_serializer=qwak_dot_workspace_dot_workspace__service__pb2.MarkBuildAsCopiedRequest.SerializeToString,
                response_deserializer=qwak_dot_workspace_dot_workspace__service__pb2.MarkBuildAsCopiedResponse.FromString,
                )
        self.CopyBuild = channel.unary_unary(
                '/qwak.workspace.management.WorkspaceManagementService/CopyBuild',
                request_serializer=qwak_dot_workspace_dot_workspace__service__pb2.CopyBuildRequest.SerializeToString,
                response_deserializer=qwak_dot_workspace_dot_workspace__service__pb2.CopyBuildResponse.FromString,
                )


class WorkspaceManagementServiceServicer(object):
    """Missing associated documentation comment in .proto file."""

    def CreateWorkspace(self, request, context):
        """Create workspace
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def UpdateWorkspace(self, request, context):
        """Update existing workspace
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def DeployWorkspace(self, request, context):
        """Deploy existing workspace
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def UndeployWorkspace(self, request, context):
        """Undeploy existing workspace
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ListWorkspaces(self, request, context):
        """List existing workspace
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetWorkspaceById(self, request, context):
        """Get existing workspace by id
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def DeleteWorkspace(self, request, context):
        """Delete existing workspace
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def UpdateWorkspaceStatusFromEdge(self, request, context):
        """Update workspace status from edge
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ListWorkspaceImages(self, request, context):
        """List workspace images
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def RegisterWorkspaceTags(self, request, context):
        """Create workspace tag
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def CountWorkspaces(self, request, context):
        """Count of workspaces
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetDefaultWorkspaceValues(self, request, context):
        """Default values for workspace spec
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def MarkBuildAsCopied(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def CopyBuild(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_WorkspaceManagementServiceServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'CreateWorkspace': grpc.unary_unary_rpc_method_handler(
                    servicer.CreateWorkspace,
                    request_deserializer=qwak_dot_workspace_dot_workspace__service__pb2.CreateWorkspaceRequest.FromString,
                    response_serializer=qwak_dot_workspace_dot_workspace__service__pb2.CreateWorkspaceResponse.SerializeToString,
            ),
            'UpdateWorkspace': grpc.unary_unary_rpc_method_handler(
                    servicer.UpdateWorkspace,
                    request_deserializer=qwak_dot_workspace_dot_workspace__service__pb2.UpdateWorkspaceRequest.FromString,
                    response_serializer=qwak_dot_workspace_dot_workspace__service__pb2.UpdateWorkspaceResponse.SerializeToString,
            ),
            'DeployWorkspace': grpc.unary_unary_rpc_method_handler(
                    servicer.DeployWorkspace,
                    request_deserializer=qwak_dot_workspace_dot_workspace__service__pb2.DeployWorkspaceRequest.FromString,
                    response_serializer=qwak_dot_workspace_dot_workspace__service__pb2.DeployWorkspaceResponse.SerializeToString,
            ),
            'UndeployWorkspace': grpc.unary_unary_rpc_method_handler(
                    servicer.UndeployWorkspace,
                    request_deserializer=qwak_dot_workspace_dot_workspace__service__pb2.UndeployWorkspaceRequest.FromString,
                    response_serializer=qwak_dot_workspace_dot_workspace__service__pb2.UndeployWorkspaceResponse.SerializeToString,
            ),
            'ListWorkspaces': grpc.unary_unary_rpc_method_handler(
                    servicer.ListWorkspaces,
                    request_deserializer=qwak_dot_workspace_dot_workspace__service__pb2.ListWorkspacesRequest.FromString,
                    response_serializer=qwak_dot_workspace_dot_workspace__service__pb2.ListWorkspacesResponse.SerializeToString,
            ),
            'GetWorkspaceById': grpc.unary_unary_rpc_method_handler(
                    servicer.GetWorkspaceById,
                    request_deserializer=qwak_dot_workspace_dot_workspace__service__pb2.GetWorkspaceByIdRequest.FromString,
                    response_serializer=qwak_dot_workspace_dot_workspace__service__pb2.GetWorkspaceByIdResponse.SerializeToString,
            ),
            'DeleteWorkspace': grpc.unary_unary_rpc_method_handler(
                    servicer.DeleteWorkspace,
                    request_deserializer=qwak_dot_workspace_dot_workspace__service__pb2.DeleteWorkspaceRequest.FromString,
                    response_serializer=qwak_dot_workspace_dot_workspace__service__pb2.DeleteWorkspaceResponse.SerializeToString,
            ),
            'UpdateWorkspaceStatusFromEdge': grpc.unary_unary_rpc_method_handler(
                    servicer.UpdateWorkspaceStatusFromEdge,
                    request_deserializer=qwak_dot_workspace_dot_workspace__service__pb2.UpdateWorkspaceStatusFromEdgeRequest.FromString,
                    response_serializer=qwak_dot_workspace_dot_workspace__service__pb2.UpdateWorkspaceStatusFromEdgeResponse.SerializeToString,
            ),
            'ListWorkspaceImages': grpc.unary_unary_rpc_method_handler(
                    servicer.ListWorkspaceImages,
                    request_deserializer=qwak_dot_workspace_dot_workspace__service__pb2.ListWorkspaceImagesRequest.FromString,
                    response_serializer=qwak_dot_workspace_dot_workspace__service__pb2.ListWorkspaceImagesResponse.SerializeToString,
            ),
            'RegisterWorkspaceTags': grpc.unary_unary_rpc_method_handler(
                    servicer.RegisterWorkspaceTags,
                    request_deserializer=qwak_dot_workspace_dot_workspace__service__pb2.RegisterWorkspaceTagRequest.FromString,
                    response_serializer=qwak_dot_workspace_dot_workspace__service__pb2.RegisterWorkspaceTagResponse.SerializeToString,
            ),
            'CountWorkspaces': grpc.unary_unary_rpc_method_handler(
                    servicer.CountWorkspaces,
                    request_deserializer=qwak_dot_workspace_dot_workspace__service__pb2.CountWorkspacesRequest.FromString,
                    response_serializer=qwak_dot_workspace_dot_workspace__service__pb2.CountWorkspacesResponse.SerializeToString,
            ),
            'GetDefaultWorkspaceValues': grpc.unary_unary_rpc_method_handler(
                    servicer.GetDefaultWorkspaceValues,
                    request_deserializer=qwak_dot_workspace_dot_workspace__service__pb2.GetDefaultWorkspaceValuesRequest.FromString,
                    response_serializer=qwak_dot_workspace_dot_workspace__service__pb2.GetDefaultWorkspaceValuesResponse.SerializeToString,
            ),
            'MarkBuildAsCopied': grpc.unary_unary_rpc_method_handler(
                    servicer.MarkBuildAsCopied,
                    request_deserializer=qwak_dot_workspace_dot_workspace__service__pb2.MarkBuildAsCopiedRequest.FromString,
                    response_serializer=qwak_dot_workspace_dot_workspace__service__pb2.MarkBuildAsCopiedResponse.SerializeToString,
            ),
            'CopyBuild': grpc.unary_unary_rpc_method_handler(
                    servicer.CopyBuild,
                    request_deserializer=qwak_dot_workspace_dot_workspace__service__pb2.CopyBuildRequest.FromString,
                    response_serializer=qwak_dot_workspace_dot_workspace__service__pb2.CopyBuildResponse.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'qwak.workspace.management.WorkspaceManagementService', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class WorkspaceManagementService(object):
    """Missing associated documentation comment in .proto file."""

    @staticmethod
    def CreateWorkspace(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/qwak.workspace.management.WorkspaceManagementService/CreateWorkspace',
            qwak_dot_workspace_dot_workspace__service__pb2.CreateWorkspaceRequest.SerializeToString,
            qwak_dot_workspace_dot_workspace__service__pb2.CreateWorkspaceResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def UpdateWorkspace(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/qwak.workspace.management.WorkspaceManagementService/UpdateWorkspace',
            qwak_dot_workspace_dot_workspace__service__pb2.UpdateWorkspaceRequest.SerializeToString,
            qwak_dot_workspace_dot_workspace__service__pb2.UpdateWorkspaceResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def DeployWorkspace(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/qwak.workspace.management.WorkspaceManagementService/DeployWorkspace',
            qwak_dot_workspace_dot_workspace__service__pb2.DeployWorkspaceRequest.SerializeToString,
            qwak_dot_workspace_dot_workspace__service__pb2.DeployWorkspaceResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def UndeployWorkspace(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/qwak.workspace.management.WorkspaceManagementService/UndeployWorkspace',
            qwak_dot_workspace_dot_workspace__service__pb2.UndeployWorkspaceRequest.SerializeToString,
            qwak_dot_workspace_dot_workspace__service__pb2.UndeployWorkspaceResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ListWorkspaces(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/qwak.workspace.management.WorkspaceManagementService/ListWorkspaces',
            qwak_dot_workspace_dot_workspace__service__pb2.ListWorkspacesRequest.SerializeToString,
            qwak_dot_workspace_dot_workspace__service__pb2.ListWorkspacesResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetWorkspaceById(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/qwak.workspace.management.WorkspaceManagementService/GetWorkspaceById',
            qwak_dot_workspace_dot_workspace__service__pb2.GetWorkspaceByIdRequest.SerializeToString,
            qwak_dot_workspace_dot_workspace__service__pb2.GetWorkspaceByIdResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def DeleteWorkspace(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/qwak.workspace.management.WorkspaceManagementService/DeleteWorkspace',
            qwak_dot_workspace_dot_workspace__service__pb2.DeleteWorkspaceRequest.SerializeToString,
            qwak_dot_workspace_dot_workspace__service__pb2.DeleteWorkspaceResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def UpdateWorkspaceStatusFromEdge(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/qwak.workspace.management.WorkspaceManagementService/UpdateWorkspaceStatusFromEdge',
            qwak_dot_workspace_dot_workspace__service__pb2.UpdateWorkspaceStatusFromEdgeRequest.SerializeToString,
            qwak_dot_workspace_dot_workspace__service__pb2.UpdateWorkspaceStatusFromEdgeResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ListWorkspaceImages(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/qwak.workspace.management.WorkspaceManagementService/ListWorkspaceImages',
            qwak_dot_workspace_dot_workspace__service__pb2.ListWorkspaceImagesRequest.SerializeToString,
            qwak_dot_workspace_dot_workspace__service__pb2.ListWorkspaceImagesResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def RegisterWorkspaceTags(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/qwak.workspace.management.WorkspaceManagementService/RegisterWorkspaceTags',
            qwak_dot_workspace_dot_workspace__service__pb2.RegisterWorkspaceTagRequest.SerializeToString,
            qwak_dot_workspace_dot_workspace__service__pb2.RegisterWorkspaceTagResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def CountWorkspaces(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/qwak.workspace.management.WorkspaceManagementService/CountWorkspaces',
            qwak_dot_workspace_dot_workspace__service__pb2.CountWorkspacesRequest.SerializeToString,
            qwak_dot_workspace_dot_workspace__service__pb2.CountWorkspacesResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetDefaultWorkspaceValues(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/qwak.workspace.management.WorkspaceManagementService/GetDefaultWorkspaceValues',
            qwak_dot_workspace_dot_workspace__service__pb2.GetDefaultWorkspaceValuesRequest.SerializeToString,
            qwak_dot_workspace_dot_workspace__service__pb2.GetDefaultWorkspaceValuesResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def MarkBuildAsCopied(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/qwak.workspace.management.WorkspaceManagementService/MarkBuildAsCopied',
            qwak_dot_workspace_dot_workspace__service__pb2.MarkBuildAsCopiedRequest.SerializeToString,
            qwak_dot_workspace_dot_workspace__service__pb2.MarkBuildAsCopiedResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def CopyBuild(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/qwak.workspace.management.WorkspaceManagementService/CopyBuild',
            qwak_dot_workspace_dot_workspace__service__pb2.CopyBuildRequest.SerializeToString,
            qwak_dot_workspace_dot_workspace__service__pb2.CopyBuildResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)
