# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: qwak/administration/runtime_configuration/v0/hosting/aws/auth.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from _qwak_proto.qwak.administration.runtime_configuration.v0.creds import secret_pb2 as qwak_dot_administration_dot_runtime__configuration_dot_v0_dot_creds_dot_secret__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nCqwak/administration/runtime_configuration/v0/hosting/aws/auth.proto\x12\x38qwak.administration.runtime_configuration.v0.hosting.aws\x1a?qwak/administration/runtime_configuration/v0/creds/secret.proto\"\x95\x01\n\rAWSAuthMethod\x12w\n\x1a\x61ws_security_token_service\x18\x02 \x01(\x0b\x32Q.qwak.administration.runtime_configuration.v0.hosting.aws.AWSSecurityTokenServiceH\x00\x42\x0b\n\tauth_type\"\x88\x01\n\x17\x41WSSecurityTokenService\x12\x61\n\x0esecret_key_ref\x18\x01 \x01(\x0b\x32G.qwak.administration.runtime_configuration.v0.creds.secret.SecretKeyRefH\x00\x42\n\n\x08location\"\x94\x01\n\x14\x41WSScopedPermissions\x12n\n\x0eworkload_scope\x18\x01 \x01(\x0b\x32T.qwak.administration.runtime_configuration.v0.hosting.aws.AWSWorkloadPermissionScopeH\x00\x42\x0c\n\nscope_type\"\xf5\x03\n\x1a\x41WSWorkloadPermissionScope\x12k\n\x0f\x61nalytics_scope\x18\x01 \x01(\x0b\x32R.qwak.administration.runtime_configuration.v0.hosting.aws.AnalyticsPermissionScope\x12}\n\x19\x62\x61tch_inference_job_scope\x18\x02 \x01(\x0b\x32Z.qwak.administration.runtime_configuration.v0.hosting.aws.BatchInferenceJobPermissionScope\x12r\n\x13\x66\x65\x61ture_store_scope\x18\x03 \x01(\x0b\x32U.qwak.administration.runtime_configuration.v0.hosting.aws.FeatureStorePermissionScope\x12w\n\x16remote_build_job_scope\x18\x04 \x01(\x0b\x32W.qwak.administration.runtime_configuration.v0.hosting.aws.RemoteBuildJobPermissionScope\"x\n\x18\x41nalyticsPermissionScope\x12\\\n\x0b\x61uth_method\x18\x01 \x01(\x0b\x32G.qwak.administration.runtime_configuration.v0.hosting.aws.AWSAuthMethod\"\x80\x01\n BatchInferenceJobPermissionScope\x12\\\n\x0b\x61uth_method\x18\x01 \x01(\x0b\x32G.qwak.administration.runtime_configuration.v0.hosting.aws.AWSAuthMethod\"{\n\x1b\x46\x65\x61tureStorePermissionScope\x12\\\n\x0b\x61uth_method\x18\x01 \x01(\x0b\x32G.qwak.administration.runtime_configuration.v0.hosting.aws.AWSAuthMethod\"}\n\x1dRemoteBuildJobPermissionScope\x12\\\n\x0b\x61uth_method\x18\x01 \x01(\x0b\x32G.qwak.administration.runtime_configuration.v0.hosting.aws.AWSAuthMethodB\xd7\x01\n1com.jfrog.ml.runtime_configuration.v0.hosting.awsP\x01Z\x9f\x01github.com/qwak-ai/qwak-platform/services/core/java/user-management/user-management-api/pb/qwak/administration/runtime_configuration/v0/hosting/aws;hosting_awsb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'qwak.administration.runtime_configuration.v0.hosting.aws.auth_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n1com.jfrog.ml.runtime_configuration.v0.hosting.awsP\001Z\237\001github.com/qwak-ai/qwak-platform/services/core/java/user-management/user-management-api/pb/qwak/administration/runtime_configuration/v0/hosting/aws;hosting_aws'
  _globals['_AWSAUTHMETHOD']._serialized_start=195
  _globals['_AWSAUTHMETHOD']._serialized_end=344
  _globals['_AWSSECURITYTOKENSERVICE']._serialized_start=347
  _globals['_AWSSECURITYTOKENSERVICE']._serialized_end=483
  _globals['_AWSSCOPEDPERMISSIONS']._serialized_start=486
  _globals['_AWSSCOPEDPERMISSIONS']._serialized_end=634
  _globals['_AWSWORKLOADPERMISSIONSCOPE']._serialized_start=637
  _globals['_AWSWORKLOADPERMISSIONSCOPE']._serialized_end=1138
  _globals['_ANALYTICSPERMISSIONSCOPE']._serialized_start=1140
  _globals['_ANALYTICSPERMISSIONSCOPE']._serialized_end=1260
  _globals['_BATCHINFERENCEJOBPERMISSIONSCOPE']._serialized_start=1263
  _globals['_BATCHINFERENCEJOBPERMISSIONSCOPE']._serialized_end=1391
  _globals['_FEATURESTOREPERMISSIONSCOPE']._serialized_start=1393
  _globals['_FEATURESTOREPERMISSIONSCOPE']._serialized_end=1516
  _globals['_REMOTEBUILDJOBPERMISSIONSCOPE']._serialized_start=1518
  _globals['_REMOTEBUILDJOBPERMISSIONSCOPE']._serialized_end=1643
# @@protoc_insertion_point(module_scope)
