# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: qwak/integration/hugging_face_integration.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n/qwak/integration/hugging_face_integration.proto\x12\x1bqwak.integration.management\"\xa4\x01\n\x16HuggingFaceIntegration\x12\x81\x01\n/hugging_face_api_token_system_secret_descriptor\x18\x01 \x01(\x0b\x32\x46.qwak.integration.management.HuggingFaceApiTokenSystemSecretDescriptorH\x00\x42\x06\n\x04\x61uth\"\x8e\x01\n\x1aHuggingFaceIntegrationSpec\x12h\n\"hugging_face_api_token_auth_config\x18\x01 \x01(\x0b\x32:.qwak.integration.management.HuggingFaceApiTokenAuthConfigH\x00\x42\x06\n\x04\x61uth\"\x8d\x01\n\x19HuggingFaceValidationSpec\x12h\n\"hugging_face_api_token_auth_config\x18\x01 \x01(\x0b\x32:.qwak.integration.management.HuggingFaceApiTokenAuthConfigH\x00\x42\x06\n\x04\x61uth\"2\n\x1dHuggingFaceApiTokenAuthConfig\x12\x11\n\tapi_token\x18\x01 \x01(\t\"^\n)HuggingFaceApiTokenSystemSecretDescriptor\x12\x13\n\x0bsecret_name\x18\x01 \x01(\t\x12\x1c\n\x14\x61pi_token_secret_key\x18\x02 \x01(\t\"\x1f\n\x1dHuggingFaceIntegrationOptionsBH\n&com.qwak.ai.management.integration.apiP\x01Z\x1cqwak/integration;integrationb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'qwak.integration.hugging_face_integration_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n&com.qwak.ai.management.integration.apiP\001Z\034qwak/integration;integration'
  _globals['_HUGGINGFACEINTEGRATION']._serialized_start=81
  _globals['_HUGGINGFACEINTEGRATION']._serialized_end=245
  _globals['_HUGGINGFACEINTEGRATIONSPEC']._serialized_start=248
  _globals['_HUGGINGFACEINTEGRATIONSPEC']._serialized_end=390
  _globals['_HUGGINGFACEVALIDATIONSPEC']._serialized_start=393
  _globals['_HUGGINGFACEVALIDATIONSPEC']._serialized_end=534
  _globals['_HUGGINGFACEAPITOKENAUTHCONFIG']._serialized_start=536
  _globals['_HUGGINGFACEAPITOKENAUTHCONFIG']._serialized_end=586
  _globals['_HUGGINGFACEAPITOKENSYSTEMSECRETDESCRIPTOR']._serialized_start=588
  _globals['_HUGGINGFACEAPITOKENSYSTEMSECRETDESCRIPTOR']._serialized_end=682
  _globals['_HUGGINGFACEINTEGRATIONOPTIONS']._serialized_start=684
  _globals['_HUGGINGFACEINTEGRATIONOPTIONS']._serialized_end=715
# @@protoc_insertion_point(module_scope)
