# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: qwak/feature_store/sources/data_source.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from _qwak_proto.qwak.feature_store.sources import batch_pb2 as qwak_dot_feature__store_dot_sources_dot_batch__pb2
from _qwak_proto.qwak.feature_store.sources import streaming_pb2 as qwak_dot_feature__store_dot_sources_dot_streaming__pb2
from _qwak_proto.qwak.feature_store.sources import data_source_attribute_pb2 as qwak_dot_feature__store_dot_sources_dot_data__source__attribute__pb2
from _qwak_proto.qwak.feature_store.v1.common.source_code import source_code_pb2 as qwak_dot_feature__store_dot_v1_dot_common_dot_source__code_dot_source__code__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n,qwak/feature_store/sources/data_source.proto\x12\x1aqwak.feature.store.sources\x1a\x1fgoogle/protobuf/timestamp.proto\x1a&qwak/feature_store/sources/batch.proto\x1a*qwak/feature_store/sources/streaming.proto\x1a\x36qwak/feature_store/sources/data_source_attribute.proto\x1a:qwak/feature_store/v1/common/source_code/source_code.proto\"\xe3\x01\n\nDataSource\x12P\n\x16\x64\x61ta_source_definition\x18\x01 \x01(\x0b\x32\x30.qwak.feature.store.sources.DataSourceDefinition\x12@\n\x08metadata\x18\x02 \x01(\x0b\x32..qwak.feature.store.sources.DataSourceMetadata\x12\x41\n\x0c\x66\x65\x61ture_sets\x18\x03 \x03(\x0b\x32+.qwak.feature.store.sources.FeatureSetBrief\"t\n\x14\x44\x61taSourceDefinition\x12\x16\n\x0e\x64\x61ta_source_id\x18\x01 \x01(\t\x12\x44\n\x10\x64\x61ta_source_spec\x18\x02 \x01(\x0b\x32*.qwak.feature.store.sources.DataSourceSpec\"\xc0\x01\n\x12\x44\x61taSourceMetadata\x12.\n\ncreated_at\x18\x01 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x12\n\ncreated_by\x18\x02 \x01(\t\x12\x34\n\x10last_modified_at\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x18\n\x10last_modified_by\x18\x04 \x01(\t\x12\x16\n\x0e\x65nvironment_id\x18\x05 \x01(\t\"\xe3\x03\n\x0e\x44\x61taSourceSpec\x12?\n\x0c\x62\x61tch_source\x18\x01 \x01(\x0b\x32\'.qwak.feature.store.sources.BatchSourceH\x00\x12\x44\n\rstream_source\x18\x02 \x01(\x0b\x32+.qwak.feature.store.sources.StreamingSourceH\x00\x12V\n\x10source_code_spec\x18\x03 \x01(\x0b\x32\x38.qwak.feature.store.v1.common.source_code.SourceCodeSpecB\x02\x18\x01\x12P\n\x16\x64\x61ta_source_attributes\x18\x04 \x01(\x0b\x32\x30.qwak.feature.store.sources.DataSourceAttributes\x12(\n\x1a\x66\x65\x61tureset_repository_name\x18\x05 \x01(\tB\x02\x18\x01H\x01\x12%\n\x1b\x64\x61ta_source_repository_name\x18\x06 \x01(\tH\x02\x42\x06\n\x04typeB\"\n featureset_repository_identifierB#\n!data_source_repository_identifier\"]\n\x0f\x46\x65\x61tureSetBrief\x12\x16\n\x0e\x66\x65\x61ture_set_id\x18\x01 \x01(\t\x12\x18\n\x10\x66\x65\x61ture_set_name\x18\x02 \x01(\t\x12\x18\n\x10\x66\x65\x61ture_set_type\x18\x03 \x01(\x05\x42X\n%com.qwak.ai.feature.store.sources.apiP\x01Z-qwak/featurestore/sources;featurestoresourcesb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'qwak.feature_store.sources.data_source_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n%com.qwak.ai.feature.store.sources.apiP\001Z-qwak/featurestore/sources;featurestoresources'
  _DATASOURCESPEC.fields_by_name['source_code_spec']._options = None
  _DATASOURCESPEC.fields_by_name['source_code_spec']._serialized_options = b'\030\001'
  _DATASOURCESPEC.fields_by_name['featureset_repository_name']._options = None
  _DATASOURCESPEC.fields_by_name['featureset_repository_name']._serialized_options = b'\030\001'
  _globals['_DATASOURCE']._serialized_start=310
  _globals['_DATASOURCE']._serialized_end=537
  _globals['_DATASOURCEDEFINITION']._serialized_start=539
  _globals['_DATASOURCEDEFINITION']._serialized_end=655
  _globals['_DATASOURCEMETADATA']._serialized_start=658
  _globals['_DATASOURCEMETADATA']._serialized_end=850
  _globals['_DATASOURCESPEC']._serialized_start=853
  _globals['_DATASOURCESPEC']._serialized_end=1336
  _globals['_FEATURESETBRIEF']._serialized_start=1338
  _globals['_FEATURESETBRIEF']._serialized_end=1431
# @@protoc_insertion_point(module_scope)
