# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from _qwak_proto.qwak.monitoring.v0 import alerting_channel_management_service_pb2 as qwak_dot_monitoring_dot_v0_dot_alerting__channel__management__service__pb2


class AlertingChannelManagementServiceStub(object):
    """Missing associated documentation comment in .proto file."""

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.CreateAlertingChannel = channel.unary_unary(
                '/qwak.monitoring.v0.AlertingChannelManagementService/CreateAlertingChannel',
                request_serializer=qwak_dot_monitoring_dot_v0_dot_alerting__channel__management__service__pb2.CreateAlertingChannelRequest.SerializeToString,
                response_deserializer=qwak_dot_monitoring_dot_v0_dot_alerting__channel__management__service__pb2.CreateAlertingChannelResponse.FromString,
                )
        self.UpdateAlertingChannel = channel.unary_unary(
                '/qwak.monitoring.v0.AlertingChannelManagementService/UpdateAlertingChannel',
                request_serializer=qwak_dot_monitoring_dot_v0_dot_alerting__channel__management__service__pb2.UpdateAlertingChannelRequest.SerializeToString,
                response_deserializer=qwak_dot_monitoring_dot_v0_dot_alerting__channel__management__service__pb2.UpdateAlertingChannelResponse.FromString,
                )
        self.GetAlertingChannelById = channel.unary_unary(
                '/qwak.monitoring.v0.AlertingChannelManagementService/GetAlertingChannelById',
                request_serializer=qwak_dot_monitoring_dot_v0_dot_alerting__channel__management__service__pb2.GetAlertingChannelRequestById.SerializeToString,
                response_deserializer=qwak_dot_monitoring_dot_v0_dot_alerting__channel__management__service__pb2.GetAlertingChannelResponseById.FromString,
                )
        self.GetAlertingChannelByName = channel.unary_unary(
                '/qwak.monitoring.v0.AlertingChannelManagementService/GetAlertingChannelByName',
                request_serializer=qwak_dot_monitoring_dot_v0_dot_alerting__channel__management__service__pb2.GetAlertingChannelRequestByName.SerializeToString,
                response_deserializer=qwak_dot_monitoring_dot_v0_dot_alerting__channel__management__service__pb2.GetAlertingChannelResponseByName.FromString,
                )
        self.ListAlertingChannel = channel.unary_unary(
                '/qwak.monitoring.v0.AlertingChannelManagementService/ListAlertingChannel',
                request_serializer=qwak_dot_monitoring_dot_v0_dot_alerting__channel__management__service__pb2.ListAlertingChannelRequest.SerializeToString,
                response_deserializer=qwak_dot_monitoring_dot_v0_dot_alerting__channel__management__service__pb2.ListAlertingChannelResponse.FromString,
                )
        self.DeleteAlertingChannel = channel.unary_unary(
                '/qwak.monitoring.v0.AlertingChannelManagementService/DeleteAlertingChannel',
                request_serializer=qwak_dot_monitoring_dot_v0_dot_alerting__channel__management__service__pb2.DeleteAlertingChannelRequest.SerializeToString,
                response_deserializer=qwak_dot_monitoring_dot_v0_dot_alerting__channel__management__service__pb2.DeleteAlertingChannelResponse.FromString,
                )


class AlertingChannelManagementServiceServicer(object):
    """Missing associated documentation comment in .proto file."""

    def CreateAlertingChannel(self, request, context):
        """Create an alerting channel
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def UpdateAlertingChannel(self, request, context):
        """Update an alerting channel
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetAlertingChannelById(self, request, context):
        """Get an alerting channel by id
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetAlertingChannelByName(self, request, context):
        """Get an alerting channel by name
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ListAlertingChannel(self, request, context):
        """List alerting channels
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def DeleteAlertingChannel(self, request, context):
        """List alerting channels
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_AlertingChannelManagementServiceServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'CreateAlertingChannel': grpc.unary_unary_rpc_method_handler(
                    servicer.CreateAlertingChannel,
                    request_deserializer=qwak_dot_monitoring_dot_v0_dot_alerting__channel__management__service__pb2.CreateAlertingChannelRequest.FromString,
                    response_serializer=qwak_dot_monitoring_dot_v0_dot_alerting__channel__management__service__pb2.CreateAlertingChannelResponse.SerializeToString,
            ),
            'UpdateAlertingChannel': grpc.unary_unary_rpc_method_handler(
                    servicer.UpdateAlertingChannel,
                    request_deserializer=qwak_dot_monitoring_dot_v0_dot_alerting__channel__management__service__pb2.UpdateAlertingChannelRequest.FromString,
                    response_serializer=qwak_dot_monitoring_dot_v0_dot_alerting__channel__management__service__pb2.UpdateAlertingChannelResponse.SerializeToString,
            ),
            'GetAlertingChannelById': grpc.unary_unary_rpc_method_handler(
                    servicer.GetAlertingChannelById,
                    request_deserializer=qwak_dot_monitoring_dot_v0_dot_alerting__channel__management__service__pb2.GetAlertingChannelRequestById.FromString,
                    response_serializer=qwak_dot_monitoring_dot_v0_dot_alerting__channel__management__service__pb2.GetAlertingChannelResponseById.SerializeToString,
            ),
            'GetAlertingChannelByName': grpc.unary_unary_rpc_method_handler(
                    servicer.GetAlertingChannelByName,
                    request_deserializer=qwak_dot_monitoring_dot_v0_dot_alerting__channel__management__service__pb2.GetAlertingChannelRequestByName.FromString,
                    response_serializer=qwak_dot_monitoring_dot_v0_dot_alerting__channel__management__service__pb2.GetAlertingChannelResponseByName.SerializeToString,
            ),
            'ListAlertingChannel': grpc.unary_unary_rpc_method_handler(
                    servicer.ListAlertingChannel,
                    request_deserializer=qwak_dot_monitoring_dot_v0_dot_alerting__channel__management__service__pb2.ListAlertingChannelRequest.FromString,
                    response_serializer=qwak_dot_monitoring_dot_v0_dot_alerting__channel__management__service__pb2.ListAlertingChannelResponse.SerializeToString,
            ),
            'DeleteAlertingChannel': grpc.unary_unary_rpc_method_handler(
                    servicer.DeleteAlertingChannel,
                    request_deserializer=qwak_dot_monitoring_dot_v0_dot_alerting__channel__management__service__pb2.DeleteAlertingChannelRequest.FromString,
                    response_serializer=qwak_dot_monitoring_dot_v0_dot_alerting__channel__management__service__pb2.DeleteAlertingChannelResponse.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'qwak.monitoring.v0.AlertingChannelManagementService', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class AlertingChannelManagementService(object):
    """Missing associated documentation comment in .proto file."""

    @staticmethod
    def CreateAlertingChannel(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/qwak.monitoring.v0.AlertingChannelManagementService/CreateAlertingChannel',
            qwak_dot_monitoring_dot_v0_dot_alerting__channel__management__service__pb2.CreateAlertingChannelRequest.SerializeToString,
            qwak_dot_monitoring_dot_v0_dot_alerting__channel__management__service__pb2.CreateAlertingChannelResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def UpdateAlertingChannel(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/qwak.monitoring.v0.AlertingChannelManagementService/UpdateAlertingChannel',
            qwak_dot_monitoring_dot_v0_dot_alerting__channel__management__service__pb2.UpdateAlertingChannelRequest.SerializeToString,
            qwak_dot_monitoring_dot_v0_dot_alerting__channel__management__service__pb2.UpdateAlertingChannelResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetAlertingChannelById(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/qwak.monitoring.v0.AlertingChannelManagementService/GetAlertingChannelById',
            qwak_dot_monitoring_dot_v0_dot_alerting__channel__management__service__pb2.GetAlertingChannelRequestById.SerializeToString,
            qwak_dot_monitoring_dot_v0_dot_alerting__channel__management__service__pb2.GetAlertingChannelResponseById.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetAlertingChannelByName(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/qwak.monitoring.v0.AlertingChannelManagementService/GetAlertingChannelByName',
            qwak_dot_monitoring_dot_v0_dot_alerting__channel__management__service__pb2.GetAlertingChannelRequestByName.SerializeToString,
            qwak_dot_monitoring_dot_v0_dot_alerting__channel__management__service__pb2.GetAlertingChannelResponseByName.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ListAlertingChannel(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/qwak.monitoring.v0.AlertingChannelManagementService/ListAlertingChannel',
            qwak_dot_monitoring_dot_v0_dot_alerting__channel__management__service__pb2.ListAlertingChannelRequest.SerializeToString,
            qwak_dot_monitoring_dot_v0_dot_alerting__channel__management__service__pb2.ListAlertingChannelResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def DeleteAlertingChannel(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/qwak.monitoring.v0.AlertingChannelManagementService/DeleteAlertingChannel',
            qwak_dot_monitoring_dot_v0_dot_alerting__channel__management__service__pb2.DeleteAlertingChannelRequest.SerializeToString,
            qwak_dot_monitoring_dot_v0_dot_alerting__channel__management__service__pb2.DeleteAlertingChannelResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)
