"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import qwak.builds.build_pb2
import qwak.builds.build_url_pb2
import sys

if sys.version_info >= (3, 8):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

class BuildModelRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    BUILD_SPEC_FIELD_NUMBER: builtins.int
    @property
    def build_spec(self) -> qwak.builds.build_pb2.RemoteBuildSpec:
        """Requested build model spec"""
    def __init__(
        self,
        *,
        build_spec: qwak.builds.build_pb2.RemoteBuildSpec | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["build_spec", b"build_spec"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["build_spec", b"build_spec"]) -> None: ...

global___BuildModelRequest = BuildModelRequest

class BuildModelResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    def __init__(
        self,
    ) -> None: ...

global___BuildModelResponse = BuildModelResponse

class CancelBuildModelRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    BUILD_ID_FIELD_NUMBER: builtins.int
    build_id: builtins.str
    """Build id of the build to cancel"""
    def __init__(
        self,
        *,
        build_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["build_id", b"build_id"]) -> None: ...

global___CancelBuildModelRequest = CancelBuildModelRequest

class CancelBuildModelResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    def __init__(
        self,
    ) -> None: ...

global___CancelBuildModelResponse = CancelBuildModelResponse

class CreateUploadURLRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    BUILD_ID_FIELD_NUMBER: builtins.int
    build_id: builtins.str
    """Model id"""
    def __init__(
        self,
        *,
        build_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["build_id", b"build_id"]) -> None: ...

global___CreateUploadURLRequest = CreateUploadURLRequest

class CreateUploadURLResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    UPLOAD_URL_FIELD_NUMBER: builtins.int
    DOWNLOAD_URL_FIELD_NUMBER: builtins.int
    upload_url: builtins.str
    """Upload url intended for the model code upload"""
    download_url: builtins.str
    """URL which will contain the content uploaded to the upload url"""
    def __init__(
        self,
        *,
        upload_url: builtins.str = ...,
        download_url: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["download_url", b"download_url", "upload_url", b"upload_url"]) -> None: ...

global___CreateUploadURLResponse = CreateUploadURLResponse

class GetBuildVersioningUploadURLRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    PARAMS_FIELD_NUMBER: builtins.int
    @property
    def params(self) -> qwak.builds.build_url_pb2.BuildVersioningUrlParams:
        """The params to define the url."""
    def __init__(
        self,
        *,
        params: qwak.builds.build_url_pb2.BuildVersioningUrlParams | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["params", b"params"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["params", b"params"]) -> None: ...

global___GetBuildVersioningUploadURLRequest = GetBuildVersioningUploadURLRequest

class GetBuildVersioningUploadUrlsRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    PARAMS_FIELD_NUMBER: builtins.int
    @property
    def params(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[qwak.builds.build_url_pb2.BuildVersioningUrlParams]:
        """The params to define the url."""
    def __init__(
        self,
        *,
        params: collections.abc.Iterable[qwak.builds.build_url_pb2.BuildVersioningUrlParams] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["params", b"params"]) -> None: ...

global___GetBuildVersioningUploadUrlsRequest = GetBuildVersioningUploadUrlsRequest

class GetBuildVersioningUploadURLResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    class HeadersEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    UPLOAD_URL_FIELD_NUMBER: builtins.int
    PATH_FIELD_NUMBER: builtins.int
    AUTHENTICATION_DETAIL_FIELD_NUMBER: builtins.int
    HEADERS_FIELD_NUMBER: builtins.int
    upload_url: builtins.str
    """Upload url intended for the upload"""
    path: builtins.str
    """The Path we saved the artifact in"""
    @property
    def authentication_detail(self) -> global___AuthenticationDetail:
        """Authentication detail for the upload url"""
    @property
    def headers(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]:
        """Headers to be used for the upload"""
    def __init__(
        self,
        *,
        upload_url: builtins.str = ...,
        path: builtins.str = ...,
        authentication_detail: global___AuthenticationDetail | None = ...,
        headers: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["authentication_detail", b"authentication_detail"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["authentication_detail", b"authentication_detail", "headers", b"headers", "path", b"path", "upload_url", b"upload_url"]) -> None: ...

global___GetBuildVersioningUploadURLResponse = GetBuildVersioningUploadURLResponse

class AuthenticationDetail(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    JFROG_AUTHENTICATION_DETAIL_FIELD_NUMBER: builtins.int
    @property
    def jfrog_authentication_detail(self) -> global___JfrogAuthenticationDetail: ...
    def __init__(
        self,
        *,
        jfrog_authentication_detail: global___JfrogAuthenticationDetail | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["integration_type", b"integration_type", "jfrog_authentication_detail", b"jfrog_authentication_detail"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["integration_type", b"integration_type", "jfrog_authentication_detail", b"jfrog_authentication_detail"]) -> None: ...
    def WhichOneof(self, oneof_group: typing_extensions.Literal["integration_type", b"integration_type"]) -> typing_extensions.Literal["jfrog_authentication_detail"] | None: ...

global___AuthenticationDetail = AuthenticationDetail

class GetBuildVersioningUploadUrlsResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    class UploadUrlInfosEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        @property
        def value(self) -> global___UploadUrlInfo: ...
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: global___UploadUrlInfo | None = ...,
        ) -> None: ...
        def HasField(self, field_name: typing_extensions.Literal["value", b"value"]) -> builtins.bool: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    UPLOAD_URL_INFOS_FIELD_NUMBER: builtins.int
    @property
    def upload_url_infos(self) -> google.protobuf.internal.containers.MessageMap[builtins.str, global___UploadUrlInfo]:
        """Upload url intended for the upload"""
    def __init__(
        self,
        *,
        upload_url_infos: collections.abc.Mapping[builtins.str, global___UploadUrlInfo] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["upload_url_infos", b"upload_url_infos"]) -> None: ...

global___GetBuildVersioningUploadUrlsResponse = GetBuildVersioningUploadUrlsResponse

class UploadUrlInfo(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    class HeadersEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    UPLOAD_URL_FIELD_NUMBER: builtins.int
    PATH_FIELD_NUMBER: builtins.int
    HEADERS_FIELD_NUMBER: builtins.int
    upload_url: builtins.str
    """Upload url intended for the upload"""
    path: builtins.str
    """The Path we saved the artifact in"""
    @property
    def headers(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]:
        """Headers to be used for the upload"""
    def __init__(
        self,
        *,
        upload_url: builtins.str = ...,
        path: builtins.str = ...,
        headers: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["headers", b"headers", "path", b"path", "upload_url", b"upload_url"]) -> None: ...

global___UploadUrlInfo = UploadUrlInfo

class JfrogAuthenticationDetail(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    USERNAME_FIELD_NUMBER: builtins.int
    TOKEN_FIELD_NUMBER: builtins.int
    username: builtins.str
    token: builtins.str
    def __init__(
        self,
        *,
        username: builtins.str = ...,
        token: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["token", b"token", "username", b"username"]) -> None: ...

global___JfrogAuthenticationDetail = JfrogAuthenticationDetail

class GetBuildVersioningDownloadURLRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    PARAMS_FIELD_NUMBER: builtins.int
    @property
    def params(self) -> qwak.builds.build_url_pb2.BuildVersioningUrlParams:
        """The params to define the url."""
    def __init__(
        self,
        *,
        params: qwak.builds.build_url_pb2.BuildVersioningUrlParams | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["params", b"params"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["params", b"params"]) -> None: ...

global___GetBuildVersioningDownloadURLRequest = GetBuildVersioningDownloadURLRequest

class GetBuildVersioningDownloadUrLsRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    PARAMS_FIELD_NUMBER: builtins.int
    @property
    def params(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[qwak.builds.build_url_pb2.BuildVersioningUrlParams]:
        """The params to define the url."""
    def __init__(
        self,
        *,
        params: collections.abc.Iterable[qwak.builds.build_url_pb2.BuildVersioningUrlParams] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["params", b"params"]) -> None: ...

global___GetBuildVersioningDownloadUrLsRequest = GetBuildVersioningDownloadUrLsRequest

class GetBuildVersioningDownloadURLResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    class HeadersEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    DOWNLOAD_URL_FIELD_NUMBER: builtins.int
    FILE_SIZE_FIELD_NUMBER: builtins.int
    HEADERS_FIELD_NUMBER: builtins.int
    download_url: builtins.str
    """Download url - to download the wanted artifact."""
    file_size: builtins.int
    """The size of the file."""
    @property
    def headers(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]:
        """Headers to be used for the download"""
    def __init__(
        self,
        *,
        download_url: builtins.str = ...,
        file_size: builtins.int = ...,
        headers: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["download_url", b"download_url", "file_size", b"file_size", "headers", b"headers"]) -> None: ...

global___GetBuildVersioningDownloadURLResponse = GetBuildVersioningDownloadURLResponse

class GetBuildVersioningDownloadUrlsResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    class DownloadUrlInfosEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        @property
        def value(self) -> global___DownloadUrlInfo: ...
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: global___DownloadUrlInfo | None = ...,
        ) -> None: ...
        def HasField(self, field_name: typing_extensions.Literal["value", b"value"]) -> builtins.bool: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    DOWNLOAD_URL_INFOS_FIELD_NUMBER: builtins.int
    @property
    def download_url_infos(self) -> google.protobuf.internal.containers.MessageMap[builtins.str, global___DownloadUrlInfo]: ...
    def __init__(
        self,
        *,
        download_url_infos: collections.abc.Mapping[builtins.str, global___DownloadUrlInfo] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["download_url_infos", b"download_url_infos"]) -> None: ...

global___GetBuildVersioningDownloadUrlsResponse = GetBuildVersioningDownloadUrlsResponse

class DownloadUrlInfo(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    class HeadersEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    DOWNLOAD_URL_FIELD_NUMBER: builtins.int
    FILE_SIZE_FIELD_NUMBER: builtins.int
    HEADERS_FIELD_NUMBER: builtins.int
    download_url: builtins.str
    file_size: builtins.int
    """The size of the file."""
    @property
    def headers(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
    def __init__(
        self,
        *,
        download_url: builtins.str = ...,
        file_size: builtins.int = ...,
        headers: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["download_url", b"download_url", "file_size", b"file_size", "headers", b"headers"]) -> None: ...

global___DownloadUrlInfo = DownloadUrlInfo

class ListBuildVersioningTagsRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    BUILD_VERSIONING_TAGS_FIELD_NUMBER: builtins.int
    @property
    def build_versioning_tags(self) -> qwak.builds.build_url_pb2.BuildVersioningTags:
        """The params to define the urls."""
    def __init__(
        self,
        *,
        build_versioning_tags: qwak.builds.build_url_pb2.BuildVersioningTags | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["build_versioning_tags", b"build_versioning_tags"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["build_versioning_tags", b"build_versioning_tags"]) -> None: ...

global___ListBuildVersioningTagsRequest = ListBuildVersioningTagsRequest

class ListBuildVersioningTagsResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    BUILD_VERSIONING_TAGS_PROPERTIES_FIELD_NUMBER: builtins.int
    UI_DIRECT_LINK_FIELD_NUMBER: builtins.int
    @property
    def build_versioning_tags_properties(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[qwak.builds.build_url_pb2.BuildVersioningTagsProperties]:
        """Download urls - to download the wanted artifacts."""
    ui_direct_link: builtins.str
    """Direct build link"""
    def __init__(
        self,
        *,
        build_versioning_tags_properties: collections.abc.Iterable[qwak.builds.build_url_pb2.BuildVersioningTagsProperties] | None = ...,
        ui_direct_link: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["build_versioning_tags_properties", b"build_versioning_tags_properties", "ui_direct_link", b"ui_direct_link"]) -> None: ...

global___ListBuildVersioningTagsResponse = ListBuildVersioningTagsResponse

class CreateDataTableRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    MODEL_ID_FIELD_NUMBER: builtins.int
    BUILD_ID_FIELD_NUMBER: builtins.int
    TAG_FIELD_NUMBER: builtins.int
    TABLE_FIELD_NUMBER: builtins.int
    PATH_FIELD_NUMBER: builtins.int
    model_id: builtins.str
    """The model Id"""
    build_id: builtins.str
    """The build Id"""
    tag: builtins.str
    """The tag save data by."""
    @property
    def table(self) -> qwak.builds.build_pb2.DataTableDefinition:
        """Table Definition"""
    path: builtins.str
    """The path where the data is saved in"""
    def __init__(
        self,
        *,
        model_id: builtins.str = ...,
        build_id: builtins.str = ...,
        tag: builtins.str = ...,
        table: qwak.builds.build_pb2.DataTableDefinition | None = ...,
        path: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["table", b"table"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["build_id", b"build_id", "model_id", b"model_id", "path", b"path", "table", b"table", "tag", b"tag"]) -> None: ...

global___CreateDataTableRequest = CreateDataTableRequest

class CreateDataTableResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    def __init__(
        self,
    ) -> None: ...

global___CreateDataTableResponse = CreateDataTableResponse

class GetBaseDockerImageNameRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    BASE_DOCKER_IMAGE_TYPE_FIELD_NUMBER: builtins.int
    base_docker_image_type: qwak.builds.build_pb2.BaseDockerImageType.ValueType
    def __init__(
        self,
        *,
        base_docker_image_type: qwak.builds.build_pb2.BaseDockerImageType.ValueType = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["base_docker_image_type", b"base_docker_image_type"]) -> None: ...

global___GetBaseDockerImageNameRequest = GetBaseDockerImageNameRequest

class GetBaseDockerImageNameResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    BASE_DOCKER_IMAGE_NAME_FIELD_NUMBER: builtins.int
    base_docker_image_name: builtins.str
    def __init__(
        self,
        *,
        base_docker_image_name: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["base_docker_image_name", b"base_docker_image_name"]) -> None: ...

global___GetBaseDockerImageNameResponse = GetBaseDockerImageNameResponse

class SaveArtifactPathRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ARTIFACT_PATH_SPEC_FIELD_NUMBER: builtins.int
    @property
    def artifact_path_spec(self) -> qwak.builds.build_url_pb2.BuildArtifactPathSpec:
        """The artifact path specification"""
    def __init__(
        self,
        *,
        artifact_path_spec: qwak.builds.build_url_pb2.BuildArtifactPathSpec | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["artifact_path_spec", b"artifact_path_spec"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["artifact_path_spec", b"artifact_path_spec"]) -> None: ...

global___SaveArtifactPathRequest = SaveArtifactPathRequest

class SaveArtifactPathResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    def __init__(
        self,
    ) -> None: ...

global___SaveArtifactPathResponse = SaveArtifactPathResponse

class ListBuildArtifactsRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    BUILD_ID_FIELD_NUMBER: builtins.int
    build_id: builtins.str
    """The build Id to list the artifacts for"""
    def __init__(
        self,
        *,
        build_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["build_id", b"build_id"]) -> None: ...

global___ListBuildArtifactsRequest = ListBuildArtifactsRequest

class ListBuildArtifactsResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ARTIFACTS_FIELD_NUMBER: builtins.int
    @property
    def artifacts(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[qwak.builds.build_url_pb2.BuildArtifact]:
        """The build's artifacts"""
    def __init__(
        self,
        *,
        artifacts: collections.abc.Iterable[qwak.builds.build_url_pb2.BuildArtifact] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["artifacts", b"artifacts"]) -> None: ...

global___ListBuildArtifactsResponse = ListBuildArtifactsResponse

class DetachBuildsFromModelVersionsRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    MODEL_VERSION_IDS_FIELD_NUMBER: builtins.int
    @property
    def model_version_ids(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]:
        """The model versions to detach"""
    def __init__(
        self,
        *,
        model_version_ids: collections.abc.Iterable[builtins.str] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["model_version_ids", b"model_version_ids"]) -> None: ...

global___DetachBuildsFromModelVersionsRequest = DetachBuildsFromModelVersionsRequest

class DetachBuildsFromModelVersionsResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    def __init__(
        self,
    ) -> None: ...

global___DetachBuildsFromModelVersionsResponse = DetachBuildsFromModelVersionsResponse
