# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: qwak/admiral/secret/v0/secret_service.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from _qwak_proto.qwak.admiral.secret.v0 import secret_pb2 as qwak_dot_admiral_dot_secret_dot_v0_dot_secret__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n+qwak/admiral/secret/v0/secret_service.proto\x12\x16qwak.admiral.secret.v0\x1a#qwak/admiral/secret/v0/secret.proto\"g\n\x1bSetEnvironmentSecretRequest\x12H\n\x07options\x18\x01 \x01(\x0b\x32\x37.qwak.admiral.secret.v0.SetUserEnvironmentSecretOptions\"\x1e\n\x1cSetEnvironmentSecretResponse\"i\n\x1e\x44\x65leteEnvironmentSecretRequest\x12G\n\nidentifier\x18\x01 \x01(\x0b\x32\x33.qwak.admiral.secret.v0.EnvironmentSecretIdentifier\"!\n\x1f\x44\x65leteEnvironmentSecretResponse\"\x1b\n\x19ListAccountSecretsRequest\"]\n\x1aListAccountSecretsResponse\x12?\n\x0f\x61\x63\x63ount_secrets\x18\x01 \x01(\x0b\x32&.qwak.admiral.secret.v0.AccountSecrets2\x9d\x03\n\rSecretService\x12\x81\x01\n\x14SetEnvironmentSecret\x12\x33.qwak.admiral.secret.v0.SetEnvironmentSecretRequest\x1a\x34.qwak.admiral.secret.v0.SetEnvironmentSecretResponse\x12\x8a\x01\n\x17\x44\x65leteEnvironmentSecret\x12\x36.qwak.admiral.secret.v0.DeleteEnvironmentSecretRequest\x1a\x37.qwak.admiral.secret.v0.DeleteEnvironmentSecretResponse\x12{\n\x12ListAccountSecrets\x12\x31.qwak.admiral.secret.v0.ListAccountSecretsRequest\x1a\x32.qwak.admiral.secret.v0.ListAccountSecretsResponseB\x8c\x01\n\x1d\x63om.qwak.ai.admiral.secret.v0P\x01Zigithub.com/qwak-ai/qwak-platform/services/core/go/admiral/admiral-api/pb/qwak/admiral/secret/v0;secret_v0b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'qwak.admiral.secret.v0.secret_service_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\035com.qwak.ai.admiral.secret.v0P\001Zigithub.com/qwak-ai/qwak-platform/services/core/go/admiral/admiral-api/pb/qwak/admiral/secret/v0;secret_v0'
  _globals['_SETENVIRONMENTSECRETREQUEST']._serialized_start=108
  _globals['_SETENVIRONMENTSECRETREQUEST']._serialized_end=211
  _globals['_SETENVIRONMENTSECRETRESPONSE']._serialized_start=213
  _globals['_SETENVIRONMENTSECRETRESPONSE']._serialized_end=243
  _globals['_DELETEENVIRONMENTSECRETREQUEST']._serialized_start=245
  _globals['_DELETEENVIRONMENTSECRETREQUEST']._serialized_end=350
  _globals['_DELETEENVIRONMENTSECRETRESPONSE']._serialized_start=352
  _globals['_DELETEENVIRONMENTSECRETRESPONSE']._serialized_end=385
  _globals['_LISTACCOUNTSECRETSREQUEST']._serialized_start=387
  _globals['_LISTACCOUNTSECRETSREQUEST']._serialized_end=414
  _globals['_LISTACCOUNTSECRETSRESPONSE']._serialized_start=416
  _globals['_LISTACCOUNTSECRETSRESPONSE']._serialized_end=509
  _globals['_SECRETSERVICE']._serialized_start=512
  _globals['_SECRETSERVICE']._serialized_end=925
# @@protoc_insertion_point(module_scope)
