# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: qwak/administration/authenticated_user/v1/details.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n7qwak/administration/authenticated_user/v1/details.proto\x12)qwak.administration.authenticated_user.v1\"/\n\x0bUserDetails\x12\n\n\x02id\x18\x01 \x01(\t\x12\x14\n\x0c\x64isplay_name\x18\x02 \x01(\t\"|\n\x12\x45nvironmentDetails\x12\n\n\x02id\x18\x01 \x01(\t\x12Z\n\rconfiguration\x18\x02 \x01(\x0b\x32\x43.qwak.administration.authenticated_user.v1.EnvironmentConfiguration\"\xa5\x02\n\x18\x45nvironmentConfiguration\x12\x19\n\x11\x65\x64ge_services_url\x18\x01 \x01(\t\x12\x1d\n\x15management_access_url\x18\x06 \x01(\t\x12\x15\n\rmodel_api_url\x18\x02 \x01(\t\x12\x1e\n\x16\x61nalytics_data_api_url\x18\x03 \x01(\t\x12\x1d\n\x15object_storage_bucket\x18\x04 \x01(\t\x12\x19\n\x11\x62i_system_api_key\x18\x05 \x01(\t\x12^\n\x13\x63loud_configuration\x18\x07 \x01(\x0b\x32\x41.qwak.administration.authenticated_user.v1.QwakCloudConfiguration\"\x8e\x01\n\x16QwakCloudConfiguration\x12\x63\n\x17\x61ws_cloud_configuration\x18\x01 \x01(\x0b\x32@.qwak.administration.authenticated_user.v1.AwsCloudConfigurationH\x00\x42\x0f\n\rconfiguration\"a\n\x15\x41wsCloudConfiguration\x12\x0e\n\x06region\x18\x01 \x01(\t\x12\x10\n\x08role_arn\x18\x02 \x01(\t\x12\x13\n\x0b\x65xternal_id\x18\x03 \x01(\t\x12\x11\n\tworkgroup\x18\x04 \x01(\tBN\n4com.qwak.ai.administration.api.authenticated_user.v1P\x01Z\x14.;authenticated_userb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'qwak.administration.authenticated_user.v1.details_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n4com.qwak.ai.administration.api.authenticated_user.v1P\001Z\024.;authenticated_user'
  _globals['_USERDETAILS']._serialized_start=102
  _globals['_USERDETAILS']._serialized_end=149
  _globals['_ENVIRONMENTDETAILS']._serialized_start=151
  _globals['_ENVIRONMENTDETAILS']._serialized_end=275
  _globals['_ENVIRONMENTCONFIGURATION']._serialized_start=278
  _globals['_ENVIRONMENTCONFIGURATION']._serialized_end=571
  _globals['_QWAKCLOUDCONFIGURATION']._serialized_start=574
  _globals['_QWAKCLOUDCONFIGURATION']._serialized_end=716
  _globals['_AWSCLOUDCONFIGURATION']._serialized_start=718
  _globals['_AWSCLOUDCONFIGURATION']._serialized_end=815
# @@protoc_insertion_point(module_scope)
