# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: qwak/feature_store/sources/data_source_attribute.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from _qwak_proto.qwak.feature_store.v1.common.source_code import source_code_pb2 as qwak_dot_feature__store_dot_v1_dot_common_dot_source__code_dot_source__code__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n6qwak/feature_store/sources/data_source_attribute.proto\x12\x1aqwak.feature.store.sources\x1a:qwak/feature_store/v1/common/source_code/source_code.proto\"j\n\x14\x44\x61taSourceAttributes\x12R\n\x10source_code_spec\x18\x01 \x01(\x0b\x32\x38.qwak.feature.store.v1.common.source_code.SourceCodeSpecBX\n%com.qwak.ai.feature.store.sources.apiP\x01Z-qwak/featurestore/sources;featurestoresourcesb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'qwak.feature_store.sources.data_source_attribute_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n%com.qwak.ai.feature.store.sources.apiP\001Z-qwak/featurestore/sources;featurestoresources'
  _globals['_DATASOURCEATTRIBUTES']._serialized_start=146
  _globals['_DATASOURCEATTRIBUTES']._serialized_end=252
# @@protoc_insertion_point(module_scope)
