# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: qwak/execution/v1/backfill.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from _qwak_proto.qwak.feature_store.features import execution_pb2 as qwak_dot_feature__store_dot_features_dot_execution__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n qwak/execution/v1/backfill.proto\x12\x1fqwak.feature.store.execution.v1\x1a\x1fgoogle/protobuf/timestamp.proto\x1a+qwak/feature_store/features/execution.proto\"\xb2\x04\n\x0c\x42\x61\x63kfillSpec\x12\x17\n\x0f\x66\x65\x61tureset_name\x18\x01 \x01(\t\x12T\n\x11interval_backfill\x18\x02 \x01(\x0b\x32\x37.qwak.feature.store.execution.v1.IntervalBackfillWindowH\x00\x12W\n\x13\x66ull_reset_backfill\x18\x03 \x01(\x0b\x32\x38.qwak.feature.store.execution.v1.FullResetBackfillWindowH\x00\x12\x0f\n\x07\x63omment\x18\x05 \x01(\t\x12\x44\n\rbackfill_type\x18\x06 \x01(\x0b\x32-.qwak.feature.store.execution.v1.BackfillType\x12U\n\x0bno_override\x18\x07 \x01(\x0b\x32>.qwak.feature.store.execution.v1.ImplicitResourceConfigurationH\x01\x12`\n\x16\x65xplicit_configuration\x18\x08 \x01(\x0b\x32>.qwak.feature.store.execution.v1.ExplicitResourceConfigurationH\x01\x12\x13\n\x0b\x62\x61\x63kfill_id\x18\t \x01(\tB\x16\n\x14\x62\x61\x63kfill_window_typeB\x1d\n\x1bresource_configuration_type\"\x1f\n\x1dImplicitResourceConfiguration\"\x8b\x01\n\x1d\x45xplicitResourceConfiguration\x12R\n\x10\x63luster_template\x18\x01 \x01(\x0e\x32\x36.qwak.feature.store.features.execution.ClusterTemplateH\x00\x42\x16\n\x14resource_config_type\"q\n\x0c\x42\x61\x63kfillType\x12P\n\x0c\x61s_scheduled\x18\x01 \x01(\x0b\x32\x38.qwak.feature.store.execution.v1.AsScheduledBackfillTypeH\x00\x42\x0f\n\rbackfill_type\"\x19\n\x17\x41sScheduledBackfillType\"~\n\x16IntervalBackfillWindow\x12\x32\n\x0e\x62\x61\x63kfill_start\x18\x01 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x30\n\x0c\x62\x61\x63kfill_end\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\"\x19\n\x17\x46ullResetBackfillWindowB)\n%com.qwak.ai.features.execution.api.v1P\x01\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'qwak.execution.v1.backfill_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n%com.qwak.ai.features.execution.api.v1P\001'
  _globals['_BACKFILLSPEC']._serialized_start=148
  _globals['_BACKFILLSPEC']._serialized_end=710
  _globals['_IMPLICITRESOURCECONFIGURATION']._serialized_start=712
  _globals['_IMPLICITRESOURCECONFIGURATION']._serialized_end=743
  _globals['_EXPLICITRESOURCECONFIGURATION']._serialized_start=746
  _globals['_EXPLICITRESOURCECONFIGURATION']._serialized_end=885
  _globals['_BACKFILLTYPE']._serialized_start=887
  _globals['_BACKFILLTYPE']._serialized_end=1000
  _globals['_ASSCHEDULEDBACKFILLTYPE']._serialized_start=1002
  _globals['_ASSCHEDULEDBACKFILLTYPE']._serialized_end=1027
  _globals['_INTERVALBACKFILLWINDOW']._serialized_start=1029
  _globals['_INTERVALBACKFILLWINDOW']._serialized_end=1155
  _globals['_FULLRESETBACKFILLWINDOW']._serialized_start=1157
  _globals['_FULLRESETBACKFILLWINDOW']._serialized_end=1182
# @@protoc_insertion_point(module_scope)
