# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: qwak/feature_store/features/feature_set_state.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n3qwak/feature_store/features/feature_set_state.proto\x12\x1bqwak.feature.store.features\x1a\x1fgoogle/protobuf/timestamp.proto\"\x9e\x03\n\x0f\x46\x65\x61tureSetState\x12\x18\n\x10\x66\x65\x61ture_set_name\x18\x01 \x01(\t\x12\x16\n\x0e\x66\x65\x61ture_set_id\x18\x02 \x01(\t\x12R\n\x0fspark_app_state\x18\x03 \x01(\x0e\x32\x39.qwak.feature.store.features.FeatureSetLastExecutionState\x12\x44\n\x0f\x65xecutor_states\x18\x04 \x01(\x0b\x32+.qwak.feature.store.features.ExecutorStates\x12L\n\x14\x66\x65\x61ture_set_job_type\x18\x05 \x01(\x0b\x32..qwak.feature.store.features.FeatureSetJobType\x12\x15\n\rerror_message\x18\x06 \x01(\t\x12\x14\n\x0cspark_app_id\x18\x07 \x01(\t\x12\x34\n\x10last_modified_at\x18\x08 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x0e\n\x06run_id\x18\t \x01(\x03\"\xac\x02\n\x11\x46\x65\x61tureSetJobType\x12;\n\tstreaming\x18\x01 \x01(\x0b\x32&.qwak.feature.store.features.StreamingH\x00\x12\x38\n\x08\x62\x61tch_v1\x18\x02 \x01(\x0b\x32$.qwak.feature.store.features.BatchV1H\x00\x12R\n\x15streaming_aggregation\x18\x03 \x01(\x0b\x32\x31.qwak.feature.store.features.StreamingAggregationH\x00\x12@\n\x0c\x64\x65letion_job\x18\x04 \x01(\x0b\x32(.qwak.feature.store.features.DeletionJobH\x00\x42\n\n\x08job_type\"\x87\x01\n\tStreaming\x12\x35\n\x06online\x18\x01 \x01(\x0b\x32#.qwak.feature.store.features.OnlineH\x00\x12\x37\n\x07offline\x18\x02 \x01(\x0b\x32$.qwak.feature.store.features.OfflineH\x00\x42\n\n\x08sub_type\"\x08\n\x06Online\"\t\n\x07Offline\"\t\n\x07\x42\x61tchV1\"\xdf\x01\n\x14StreamingAggregation\x12:\n\trow_level\x18\x01 \x01(\x0b\x32%.qwak.feature.store.features.RowLevelH\x00\x12@\n\x08\x62\x61\x63kfill\x18\x02 \x01(\x0b\x32,.qwak.feature.store.features.BackfillSubTypeH\x00\x12=\n\ncompaction\x18\x03 \x01(\x0b\x32\'.qwak.feature.store.features.CompactionH\x00\x42\n\n\x08sub_type\"\n\n\x08RowLevel\"\x0c\n\nCompaction\"\x11\n\x0f\x42\x61\x63kfillSubType\"\xbe\x02\n\x0b\x44\x65letionJob\x12S\n\x11\x62\x61tch_v1_deletion\x18\x01 \x01(\x0b\x32\x36.qwak.feature.store.features.BatchV1DeletionJobSubTypeH\x00\x12[\n\x15streaming_v1_deletion\x18\x02 \x01(\x0b\x32:.qwak.feature.store.features.StreamingV1DeletionJobSubTypeH\x00\x12m\n\x1estreaming_aggregation_deletion\x18\x03 \x01(\x0b\x32\x43.qwak.feature.store.features.StreamingAggregationDeletionJobSubTypeH\x00\x42\x0e\n\x0cjob_sub_type\"\x1b\n\x19\x42\x61tchV1DeletionJobSubType\"\x1f\n\x1dStreamingV1DeletionJobSubType\"(\n&StreamingAggregationDeletionJobSubType\"U\n\x0e\x45xecutorStates\x12\x43\n\x0f\x65xecutor_states\x18\x01 \x03(\x0b\x32*.qwak.feature.store.features.ExecutorState\"p\n\rExecutorState\x12\x15\n\rexecutor_name\x18\x01 \x01(\t\x12H\n\x05state\x18\x02 \x01(\x0e\x32\x39.qwak.feature.store.features.FeatureSetLastExecutionState*\xd5\x01\n\x1c\x46\x65\x61tureSetLastExecutionState\x12\x0b\n\x07UNKNOWN\x10\x00\x12\n\n\x06\x46\x41ILED\x10\x01\x12\x0b\n\x07SUCCESS\x10\x02\x12\x10\n\x0cINVALIDATING\x10\x03\x12\r\n\tSUBMITTED\x10\x04\x12\x0b\n\x07RUNNING\x10\x05\x12\r\n\tCOMPLETED\x10\x06\x12\x15\n\x11SUBMISSION_FAILED\x10\x07\x12\x11\n\rPENDING_RERUN\x10\x08\x12\x0e\n\nSUCCEEDING\x10\t\x12\x0b\n\x07\x46\x41ILING\x10\n\x12\x0b\n\x07PENDING\x10\x0b\x42[\n&com.qwak.ai.feature.store.features.apiP\x01Z/qwak/featurestore/features;featurestorefeaturesb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'qwak.feature_store.features.feature_set_state_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n&com.qwak.ai.feature.store.features.apiP\001Z/qwak/featurestore/features;featurestorefeatures'
  _globals['_FEATURESETLASTEXECUTIONSTATE']._serialized_start=1905
  _globals['_FEATURESETLASTEXECUTIONSTATE']._serialized_end=2118
  _globals['_FEATURESETSTATE']._serialized_start=118
  _globals['_FEATURESETSTATE']._serialized_end=532
  _globals['_FEATURESETJOBTYPE']._serialized_start=535
  _globals['_FEATURESETJOBTYPE']._serialized_end=835
  _globals['_STREAMING']._serialized_start=838
  _globals['_STREAMING']._serialized_end=973
  _globals['_ONLINE']._serialized_start=975
  _globals['_ONLINE']._serialized_end=983
  _globals['_OFFLINE']._serialized_start=985
  _globals['_OFFLINE']._serialized_end=994
  _globals['_BATCHV1']._serialized_start=996
  _globals['_BATCHV1']._serialized_end=1005
  _globals['_STREAMINGAGGREGATION']._serialized_start=1008
  _globals['_STREAMINGAGGREGATION']._serialized_end=1231
  _globals['_ROWLEVEL']._serialized_start=1233
  _globals['_ROWLEVEL']._serialized_end=1243
  _globals['_COMPACTION']._serialized_start=1245
  _globals['_COMPACTION']._serialized_end=1257
  _globals['_BACKFILLSUBTYPE']._serialized_start=1259
  _globals['_BACKFILLSUBTYPE']._serialized_end=1276
  _globals['_DELETIONJOB']._serialized_start=1279
  _globals['_DELETIONJOB']._serialized_end=1597
  _globals['_BATCHV1DELETIONJOBSUBTYPE']._serialized_start=1599
  _globals['_BATCHV1DELETIONJOBSUBTYPE']._serialized_end=1626
  _globals['_STREAMINGV1DELETIONJOBSUBTYPE']._serialized_start=1628
  _globals['_STREAMINGV1DELETIONJOBSUBTYPE']._serialized_end=1659
  _globals['_STREAMINGAGGREGATIONDELETIONJOBSUBTYPE']._serialized_start=1661
  _globals['_STREAMINGAGGREGATIONDELETIONJOBSUBTYPE']._serialized_end=1701
  _globals['_EXECUTORSTATES']._serialized_start=1703
  _globals['_EXECUTORSTATES']._serialized_end=1788
  _globals['_EXECUTORSTATE']._serialized_start=1790
  _globals['_EXECUTORSTATE']._serialized_end=1902
# @@protoc_insertion_point(module_scope)
