# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: qwak/execution/v1/streaming.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n!qwak/execution/v1/streaming.proto\x12\x1fqwak.feature.store.execution.v1\"3\n\x18OnlineStreamingIngestion\x12\x17\n\x0f\x66\x65\x61tureset_name\x18\x01 \x01(\t\"\xfe\x01\n\x19OfflineStreamingIngestion\x12\x17\n\x0f\x66\x65\x61tureset_name\x18\x01 \x01(\t\x12^\n\x11scheduled_trigger\x18\x02 \x01(\x0b\x32\x41.qwak.feature.store.execution.v1.ScheduledOfflineStreamingTriggerH\x00\x12X\n\x0emanual_trigger\x18\x03 \x01(\x0b\x32>.qwak.feature.store.execution.v1.ManualOfflineStreamingTriggerH\x00\x42\x0e\n\x0ctrigger_type\"\"\n ScheduledOfflineStreamingTrigger\"\x1f\n\x1dManualOfflineStreamingTriggerB)\n%com.qwak.ai.features.execution.api.v1P\x01\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'qwak.execution.v1.streaming_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n%com.qwak.ai.features.execution.api.v1P\001'
  _globals['_ONLINESTREAMINGINGESTION']._serialized_start=70
  _globals['_ONLINESTREAMINGINGESTION']._serialized_end=121
  _globals['_OFFLINESTREAMINGINGESTION']._serialized_start=124
  _globals['_OFFLINESTREAMINGINGESTION']._serialized_end=378
  _globals['_SCHEDULEDOFFLINESTREAMINGTRIGGER']._serialized_start=380
  _globals['_SCHEDULEDOFFLINESTREAMINGTRIGGER']._serialized_end=414
  _globals['_MANUALOFFLINESTREAMINGTRIGGER']._serialized_start=416
  _globals['_MANUALOFFLINESTREAMINGTRIGGER']._serialized_end=447
# @@protoc_insertion_point(module_scope)
